_0007

Enum _0007 

pub enum _0007 {
Show 38 variants _1, _4, _5, _8, _9, _12, _14, _18, _22, _30, _31, _33, _34, _51, _52, _53, _54, _55, _57, _58, _59, _61, _63, _65, _80, _82, _84, _85, _86, _87, _89, _90, _91, _92, _103, _128, _129, ZZZ,
}
Partner identification code qualifier

Qualifier referring to the source of codes for the identifiers of interchanging partners.

Variants



_1

DUNS (Data Universal Numbering System)

Partner identification code assigned by Dun & Bradstreet.



_4

IATA (International Air Transport Association)

Partner identification code assigned by the International Air Transport Association.



_5

INSEE (Institut National de la Statistique et des Etudes Economiques) - SIRET

French national statistics institute. SIRET means Systeme Informatique du Repertoire des entreprises et de leurs ETablissements.



_8

UCC Communications ID (Uniform Code Council Communications Identifier)

The Uniform Code Council Communications Identifier is a ten digit code used to uniquely identify physical and logical locations.



_9

DUNS (Data Universal Numbering System) with 4 digit suffix

Partner identification code assigned by Dun & Bradstreet with the 4 digit suffix.



_12

Telephone number

Partner identification code corresponds to the partner telephone number.



_14

EAN (European Article Numbering Association)

Partner identification code assigned by the European Article Numbering Association.



_18

AIAG (Automotive Industry Action Group)

Partner identification code assigned by the Automotive Industry Action Group.



_22

INSEE (Institut National de la Statistique et des Etudes Economiques) - SIREN

French national statistics institute. SIREN means Systeme Informatique du Repertoire des ENtreprises (et de leurs etablissements).



_30

ISO 6523: Organization identification

Partner identification code specified in ISO 6523 (Structures for the identification of organizations).



_31

DIN (Deutsches Institut fuer Normung)

German standardization institute.



_33

BfA (Bundesversicherungsanstalt fuer Angestellte)

German social security association.



_34

National Statistical Agency

Partner identification code assigned by a national statistical agency.



_51

GEIS (General Electric Information Services)

Partner identification code assigned by General Electric Information Services.



_52

INS (IBM Network Services)

Partner identification code assigned by IBM Network Services.



_53

Datenzentrale des Einzelhandels

German data centre for retail trade.



_54

Bundesverband der Deutschen Baustoffhaendler

German building material trade association.



_55

Bank identifier code

Partner identification code corresponds to the partner bank identification code.



_57

KTNet (Korea Trade Network Services)

Partner identification code assigned by Korea Trade Network Services.



_58

UPU (Universal Postal Union)

Partner identification code assigned by the Universal Postal Union.



_59

ODETTE (Organization for Data Exchange through Tele- Transmission in Europe)

European automotive industry project.



_61

SCAC (Standard Carrier Alpha Code)

Directory of standard multimodal carriers and tariff agent codes. The SCAC lists and codes transportation companies.



_63

ECA (Electronic Commerce Australia)

Australian association for electronic commerce.



_65

TELEBOX 400 (Deutsche Telekom)

German telecommunications service.



_80

NHS (National Health Service)

United Kingdom National Health Service.



_82

Statens Teleforvaltning

Norwegian telecommunications regulatory authority (NTRA).



_84

Athens Chamber of Commerce

Greek Chamber of Commerce.



_85

Swiss Chamber of Commerce

Swiss Chamber of Commerce.



_86

US Council for International Business

United States Council for International Business.



_87

National Federation of Chambers of Commerce and Industry

Belgium National Federation of Chambers of Commerce and Industry.



_89

Association of British Chambers of Commerce

Association of British Chambers of Commerce.



_90

SITA (Societe Internationale de Telecommunications Aeronautiques)

SITA (Societe Internationale de Telecommunications Aeronautiques).



_91

Assigned by seller or seller’s agent

Partner identification code assigned by the seller or seller’s agent.



_92

Assigned by buyer or buyer’s agent

Partner identification code assigned by the buyer or buyer’s agent.



_103

TW, Trade-van

Trade-van is an EDI VAN service center for customs, transport, and insurance in national and international trade.



_128

BCNR (Telekurs Banken Clearing Number)

Swiss national bank number assigned by Telekurs AG for the purpose of identifying a non-clearing banking institution.



_129

BPI (Telekurs Business Partner Identification)

Swiss national business number assigned by Telekurs AG for the purpose of identifying a non-clearing banking institution.



ZZZ

Mutually defined

Mutually defined between trading partners.