_2379

Enum _2379 

pub enum _2379 {
Show 76 variants _2, _3, _4, _5, _101, _102, _103, _105, _106, _107, _108, _109, _110, _201, _202, _203, _204, _205, _301, _302, _303, _304, _305, _306, _401, _402, _404, _405, _406, _501, _502, _503, _600, _601, _602, _603, _604, _608, _609, _610, _613, _614, _615, _616, _701, _702, _703, _704, _705, _706, _707, _708, _709, _710, _711, _713, _715, _716, _717, _718, _719, _720, _801, _802, _803, _804, _805, _806, _807, _808, _809, _810, _811, _812, _813, _814,
}
Date or time or period format code

Code specifying the representation of a date, time or period.

Variants



_2

DDMMYY

Calendar date: D = Day; M = Month; Y = Year.



_3

MMDDYY

Calendar date: M = Month; D = Day; Y = Year.



_4

DDMMCCYY

Calendar date C=Century; Y=Year; M=Month; D=Day.



_5

DDMMCCYYHHMM

Calendar date and time: C=Century; Y=Year; M=Month; D=Day; H=Hour; M=Minute.



_101

YYMMDD

Calendar date: Y = Year; M = Month; D = Day.



_102

CCYYMMDD

Calendar date: C = Century ; Y = Year ; M = Month ; D = Day.



_103

YYWWD

Calendar week day: Y = Year ; W = Week ; D = Day Week number 01 is always first week of January Day number 1 is always Monday.



_105

YYDDD

Calendar day: Y = Year ; D = Day January the first = Day 001 Always start numbering the days of the year from January 1st through December 31st.



_106

MMDD

Day of a month: M = Month; D = Day.



_107

DDD

Day’s number within a specific year: D = Day.



_108

WW

Week’s number within a specific year: W = Week.



_109

MM

Month’s number within a specific year: M = Month.



_110

DD

Day’s number within is a specific month: D = Day.



_201

YYMMDDHHMM

Calendar date including time without seconds: Y = Year; M = Month; D = Day; H = Hour; M = Minute.



_202

YYMMDDHHMMSS

Calendar date including time with seconds: Y = Year; M = Month; D = Day; H = Hour; m = Minutes = Seconds.



_203

CCYYMMDDHHMM

Calendar date including time with minutes: C=Century; Y=Year; M=Month; D=Day; H=Hour; M=Minutes.



_204

CCYYMMDDHHMMSS

Calendar date including time with seconds: C=Century;Y=Year; M=Month;D=Day;H=Hour;M=Minute;S=Second.



_205

CCYYMMDDHHMMZHHMM

Calendar date including time and time zone expressed in hours and minutes. ZHHMM = time zone given as offset from Coordinated Universal Time (UTC).



_301

YYMMDDHHMMZZZ

See 201 + Z = Time zone.



_302

YYMMDDHHMMSSZZZ

See 202 + Z = Time zone.



_303

CCYYMMDDHHMMZZZ

See 203 plus Z=Time zone.



_304

CCYYMMDDHHMMSSZZZ

See 204 plus Z=Time zone.



_305

MMDDHHMM

Month, day, hours, minutes; M = Month; D = Day; H = Hour; M = Minute.



_306

DDHHMM

Day, hours, minutes; D = Day; H = Hour; M = Minute.



_401

HHMM

Time without seconds: H = Hour; m = Minute.



_402

HHMMSS

Time with seconds: H = Hour; m = Minute; s = Seconds.



_404

HHMMSSZZZ

See 402 plus Z=Time zone.



_405

MMMMSS

Time without hours: m=minutes, s=seconds.



_406

ZHHMM

Offset from Coordinated Universal Time (UTC) where Z is plus (+) or minus (-).



_501

HHMMHHMM

Time span without seconds: H = Hour; m = Minute;.



_502

HHMMSS-HHMMSS

Format of period to be given without hyphen.



_503

HHMMSSZZZ-HHMMSSZZZ

Format of period to be given without hyphen.



_600

CC

Century.



_601

YY

Calendar year: Y = Year.



_602

CCYY

Calendar year including century: C = Century; Y = Year.



_603

YYS

Semester in a calendar year: Y = Year; S = Semester.



_604

CCYYS

Semester in a calendar year: C = Century; Y = Year; S = Semester.



_608

CCYYQ

Quarter in a calendar year: C = Century; Y = Year; Q = Quarter.



_609

YYMM

Month within a calendar year: Y = Year; M = Month.



_610

CCYYMM

Month within a calendar year: CC = Century; Y = Year; M = Month.



_613

YYMMA

Format of period to be given without hyphen (A = ten days period).



_614

CCYYMMA

Format of period to be given without hyphen (A = ten days period).



_615

YYWW

Week within a calendar year: Y = Year; W = Week 1st week of January = week 01.



_616

CCYYWW

Week within a calendar year: CC = Century; Y = Year; W = Week (1st week of January = week 01).



_701

YY-YY

Format of period to be given in actual message without hyphen.



_702

CCYY-CCYY

Format of period to be given in actual message without hyphen.



_703

YYS-YYS

Format of period to be given without hyphen.



_704

CCYYS-CCYYS

Format of period to be given in actual message without hyphen.



_705

YYPYYP

Format of period to be given without hyphen (P = period of 4 months).



_706

CCYYP-CCYYP

Format of period to be given without hyphen (P = period of 4 months).



_707

YYQ-YYQ

Format of period to be given without hyphen.



_708

CCYYQ-CCYYQ

Format of period to be given in actual message without hyphen.



_709

YYMM-YYMM

Format of period to be given in actual message without hyphen.



_710

CCYYMM-CCYYMM

Format of period to be given in actual message without hyphen.



_711

CCYYMMDD-CCYYMMDD

Format of period to be given in actual message without hyphen.



_713

YYMMDDHHMM-YYMMDDHHMM

Format of period to be given in actual message without hyphen.



_715

YYWW-YYWW

Format of period to be given in actual message without hyphen.



_716

CCYYWW-CCYYWW

Format of period to be given without hyphen.



_717

YYMMDD-YYMMDD

Format of period to be given in actual message without hyphen.



_718

CCYYMMDD-CCYYMMDD

Format of period to be given without hyphen.



_719

CCYYMMDDHHMM-CCYYMMDDHHMM

A period of time which includes the century, year, month, day, hour and minute. Format of period to be given in actual message without hyphen.



_720

DHHMM-DHHMM

Format of period to be given without hyphen (D=day of the week, 1=Monday; 2=Tuesday; … 7=Sunday).



_801

Year

To indicate a quantity of years.



_802

Month

To indicate a quantity of months.



_803

Week

To indicate a quantity of weeks.



_804

Day

To indicate a quantity of days.



_805

Hour

To indicate a quantity of hours.



_806

Minute

To indicate a quantity of minutes.



_807

Second

To indicate a quantity of seconds.



_808

Semester

To indicate a quantity of semesters (six months).



_809

Four months period

To indicate a quantity of four months periods.



_810

Trimester

To indicate a quantity of trimesters (three months).



_811

Half month

To indicate a quantity of half months.



_812

Ten days

To indicate a quantity of ten days periods.



_813

Day of the week

Numeric representation of the day (Monday = 1).



_814

Working days

Number of working days.