_3155

Enum _3155 

pub enum _3155 {
Show 34 variants AA, AB, AC, AD, AE, AF, AG, AH, AI, AJ, AK, AL, AM, AN, CA, EM, EX, FT, FX, GM, MA, PB, SW, TE, TG, TL, TM, TT, TX, XF, XG, XH, XI, XJ,
}
Communication address code qualifier

Code qualifying the communication address.

Variants



AA

Circuit switching

A process that, on demand, connects two or more data terminal equipments and permits the exclusive use of a data circuit between them until the connection is released (ISO).



AB

SITA

Communications number assigned by Societe Internationale de Telecommunications Aeronautiques (SITA).



AC

ARINC

Communications number assigned by Aeronautical Radio Inc.



AD

AT&T mailbox

AT&T mailbox identifier.



AE

Peripheral device

Peripheral device identification.



AF

U.S. Defense Switched Network

The switched telecommunications network of the United States Department of Defense.



AG

U.S. federal telecommunications system

The switched telecommunications network of the United States government.



AH

World Wide Web

Data exchange via the World Wide Web.



AI

International calling country code

Identifies that portion of an international telephone number representing the country code to be used when calling internationally.



AJ

Alternate telephone

Identifies the alternate telephone number.



AK

Videotex number

Code that identifies the communications number for the online videotex service.



AL

Cellular phone

Identifies the cellular phone number.



AM

International telephone direct line

The international telephone direct line number.



AN

O.F.T.P. (ODETTE File Transfer Protocol)

ODETTE File Transfer Protocol.



CA

Cable address

EDI transmission



EM

Number identifying the service and service user. EI, Electronic mail

Exchange of mail by electronic means.



EX

Extension

Telephone extension.



FT

File transfer access method

According to ISO.



FX

Telefax

Device used for transmitting and reproducing fixed graphic material (as printing) by means of signals over telephone lines or other electronic transmission media.



GM

GEIS (General Electric Information Service) mailbox

IBM information exchange



MA

Internal mail IE,

Internal mail address/number. IM, Mail

Postal service document delivery.



PB

Postbox number

Packet switching



SW

The process of routing and transferring data by means of addressed packets so that a channel is occupied only during the transmission; upon completion of the transmission the channel is made available for the transfer of other packets (ISO). PS, S.W.I.F.T.

Communications address assigned by Society for Worldwide Interbank Financial Telecommunications s.c.



TE

Telephone

Voice/data transmission by telephone.



TG

Telegraph

Text transmission via telegraph.



TL

Telex

Transmission of text/data via telex.



TM

Telemail

Transmission of text/data via telemail.



TT

Teletext

Transmission of text/data via teletext.



TX

TWX

Communication service involving Teletypewriter machines connected by wire or electronic transmission media. Teletypewriter machines are the devices used to send and receive signals and produce hardcopy from them.



XF

X.400 address

The X.400 address.



XG

Pager

Identifies that the communication number is for a pager.



XH

International telephone switchboard

The international telephone switchboard number.



XI

National telephone direct line

The national telephone direct line number.



XJ

National telephone switchboard

The national telephone switchboard number.