pub enum _4053 {
_1,
_2,
}Expand description
Delivery or transport terms description code
Code specifying the delivery or transport terms.
Variants
_1
Delivery arranged by the supplier
Indicates that the supplier will arrange delivery of the goods.
_2
Delivery arranged by logistic service provider
Code indicating that the logistic service provider has arranged the delivery of goods.