pub enum _4055 {
_1,
_2,
_3,
_4,
_5,
_6,
}Expand description
Delivery or transport terms function code
Code specifying the function of delivery or transport terms.
Variants
_1
Price condition
Description to be provided.
_2
Despatch condition
Condition requested by the customer under which the supplier shall deliver: Extent of freight costs, means of transport.
_3
Price and despatch condition
Description to be provided.
_4
Collected by customer
Indicates that the customer will pick up the goods at the supplier. He will take care of the means of transport.
_5
Transport condition
Specifies the conditions under which the transport takes place under the responsibility of the carrier.
_6
Delivery condition
Specifies the conditions under which the goods must be delivered to the consignee.