_4065

Enum _4065 

pub enum _4065 {
Show 40 variants _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17, _18, _19, _20, _21, _22, _23, _24, _25, _26, _27, _28, _29, _30, _31, _32, _33, _34, _35, _36, _37, _38, _39, _40,
}
4065 Contract and carriage condition code

Code to identify the conditions of contract and carriage.

Variants



_1

AVC conditions General conditions of transport 1983 latest revision laid down by the Stichting Vervoeradres The Hague.



_2

Special agreement for parcels transport Appliance of a non published special agreement signed between a customer and the carrier (mandatory requested by the consignor) for parcels transport.



_3

Special agreement for full loading transport Appliance of a non published special agreement signed between a customer and the carrier (mandatory requested by the consignor) for full load transport.



_4

Combined transport A transport which involves more than one mode of transportation.



_5

FIATA combined transport bill of lading Standard conditions of a combined transport bill of lading issued by FIATA.



_6

Freight forwarders national conditions The contract and carriage conditions as established by freight forwarders on a national basis.



_7

Normal tariff, parcels transport Appliance of the published legal tariff in case of parcels transport (required or not by the consignor.



_8

Normal tariff, full loading transport Appliance of the published legal tariff in case of full load transport (required or not by the consignor).



_9

Ordinary Carrier will choose the cheapest tariff in the legally published tariffs for parcels or full load transports (no tariff required by the consignor).



_10

Port to port The transport will only be port to port, no inland transport would have to be provided under the contract.



_11

CMR carnet Conditions in accordance with the convention of the contract for the international carriage of goods by road.



_12

Special tariff, parcels transport Appliance of the legally published “special” tariff in case or parcels transport (tariff requested by the consignor).



_13

Special tariff, full transport Appliance of the legally published “special tariff” in case of full load transport (tariff requested by the consignor).



_14

Through transport The transport that is contracted not only from port to port, but from one inland location to another inland location.



_15

Cancel space allocation Indication that space previously allocated on a flight is to be cancelled.



_16

Report sale of space Indication that a sale has been made against a space allocation on a specific flight.



_17

Alternative space allocation Indication that space is being requested for a specific flight and that an alternative is acceptable.



_18

No alternative space allocation Indication that space is being requested for a specific flight and that an alternative is not acceptable.



_19

Allotment sale Indication that space is being sold against a space allocation allotment on a specific flight.



_20

Confirmation of space Indication that space requested has been confirmed on a specific flight.



_21

Unable to confirm Indication that airline is unable to confirm the space allocation on a specific flight.



_22

Non-operative flight Indication that airline is unable to confirm space on a specific flight since the flight does not operate.



_23

Wait list Indication that the space allocation request has been assigned to a wait list.



_24

Prior space allocation request Indication that a space allocation on a specific flight has already been requested.



_25

Holding confirmed space allocation Indication that space is being held as confirmed on a specific flight.



_26

Holding wait list Indication that space allocation request on a specific flight has been assigned to a wait list.



_27

Door-to-door The carrier is responsible for the intermodal carriage of cargo including both the pre-carriage and the on- carriage.



_28

Door-to-pier The carrier is responsible for the intermodal carriage of cargo including the pre-carriage, but excluding the on-carriage.



_29

Pier-to-door The carrier is responsible for the intermodal carriage of cargo including the on-carriage, but excluding the pre-carriage.



_30

Pier-to-pier The carrier of intermodal cargo is only responsible for the main carriage.



_31

Space cancellation noted Indication that space previously allocated on a means of transport has been cancelled.



_32

Mini landbridge service Cargo moving from a coastal port for delivery at an inland location or cargo received at an inland location moving to a coastal port for subsequent ocean transportation.



_33

Space cancellation noted Indication that space previously allocated on a flight has been cancelled.



_34

Speed level - required Maximum speed required on an itinerary or part of this itinerary to be able to assume some services.



_35

Speed level - adopted Real speed used on an itinerary or part of this itinerary (for technical reasons, some limitation can be imposed or some higher speed could be used).



_36

Normal tariff, less than full load transport Application of the published legal tariff in case of less than full load transport (required or not by the consignor).



_37

Re-expedition special tariff Indication that a special tariff must be used in the case of a re-expedition.



_38

Transport arrangement by the requester The service requester has the responsibility of making transport arrangement.



_39

Transport arrangement by the provider The service provider has the responsibility of making transport arrangement.



_40

Transport arrangement by the patient The patient has the responsibility of making transport arrangement.