_4215

Enum _4215 

pub enum _4215 {
Show 29 variants A, AA, AB, AC, AD, CA, CC, CF, DF, FO, IC, MX, NC, NS, PA, PB, PC, PE, PO, PP, PU, RC, RF, RS, TP, WC, WD, WE, ZZZ,
}
Transport charges payment method code

Code specifying the payment method for transport charges.

Variants



A

Account

The charges are to be charged to an account.



AA

Cash on delivery service charge paid by consignor

An indication that the consignor is responsible for the payment of the cash on delivery service charge.



AB

Cash on delivery service charge paid by consignee

An indication that the consignee is responsible for the payment of the cash on delivery service charge.



AC

Insurance costs paid by consignor

An indication that the consignor is responsible for the payment of the insurance costs.



AD

Insurance costs paid by consignee

An indication that the consignee is responsible for the payment of the insurance costs.



CA

Advance collect

The amount of freight or other charge on a shipment advanced by one transportation line to another or to the shipper, to be collected from consignee.



CC

Collect

A shipment on which freight charges will be paid by consignee.



CF

Collect, freight credited to payment customer

The freight is collect but has been paid by the shipper and will be credited to that party.



DF

Defined by buyer and seller



FO

FOB port of call

Title and control of goods pass to the buyer at port of call. Responsibility for export taxes and cost of documents for overseas shipments have not been specified.



IC

Information copy, no payment due

Transaction set has been provided for information only.



MX

Mixed

The consignment is partially collect and partially prepaid.



NC

Service freight, no charge

The consignment is shipped on a service basis and there is no freight charge.



NS

Not specified



PA

Advance prepaid

Costs have been paid in advance.



PB

Customer pick-up/backhaul

Buyer’s private carriage picks up the goods as a return load to the buyer’s facility.



PC

Prepaid but charged to customer

shipping charges have been paid in advance of shipment but are charged back to consignee usually as line item on invoice for the purchased goods.



PE

Payable elsewhere

Place of payment not known at the begin of conveyance.



PO

Prepaid only

Payment in advance of freight and/or other charges prior to delivery of shipment at destination, usually by shipper at point of origin.



PP

Prepaid (by seller)

Seller of goods makes payment to carrier for freight charges prior to shipment.



PU

Pickup

Customer is responsible for payment of pickup charges at shipping point.



RC

Return container freight paid by customer

The freight for returning the container is paid by the customer.



RF

Return container freight free

There is no freight charge for returning the container.



RS

Return container freight paid by supplier

The freight charge for returning the container is paid by the supplier.



TP

Third party pay

A third party, someone other than buyer or seller, is identified as responsible for payment of shipping charges.



WC

Weight condition

Description to be provided.



WD

Paid by supplier

Transport charges will be paid by the supplier.



WE

Paid by buyer

Transport charges will be paid by the buyer.



ZZZ

Mutually defined