pub enum _4219 {
_1,
_2,
_3,
_4,
}Expand description
Transport service priority code
Code specifying the priority of a transport service.
Variants
_1
Express
Express treatment (if by rail, legal express regime for parcels transport).
_2
High speed
Transport under legal international rail convention (CIM) concluded between rail organizations and based on fast routing and specified timetables.
_3
Normal speed
Transport under legal international rail convention (CIM) concluded between rail organizations.
_4
Post service
Transport under conditions specified by UPU (Universal Postal Union) and Rail organizations (parcels transport only).