pub enum _4237 {
A,
B,
C,
P,
}Expand description
Payment arrangement code
Code specifying the arrangements for a payment.
Variants
A
Payable elsewhere
Responsibility for payment of transport charges unknown at time of departure.
B
Third party to pay
A third party to pay the freight bill is known at the time of shipment.
C
Collect
Charges are (to be) collected from the consignee at the destination.
P
Prepaid
Charges are (to be) prepaid before the transport actually leaves.