_5237

Enum _5237 

pub enum _5237 {
Show 24 variants _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17, _18, _19, _20, _21, _22, _23, _24,
}
Charge category code

Code specifying the category of charges.

Variants



_1

All charges

All amounts calculated by the carrier in accordance with tariffs or in case of special events during the voyage (e.g. Rail - freights costs - additional costs).



_2

Additional charges

Charges calculated by the carrier for specific events like re-weighting, re-loading, unexpected operations, services required during the voyage, etc.



_3

Transport charges + additional charges

Transport charges plus Additional charges (e.g. for re- loading, re-weighting or unexpected operations) that must be precised in the payment conditions by the consignor (other charges must be taken in account by the consignee).



_4

Basic freight

The basic freight payable on the cargo as per tariff.



_5

Destination haulage charges

Haulage charges for transporting goods to the destination.



_6

Disbursement

Sums paid out by ship’s agent at a port and recovered from the carrier.



_7

Destination port charges

Charges payable at the port of destination.



_8

Miscellaneous charges

Miscellaneous charges not otherwise categorized.



_9

Transport charges up to a specified location

Transport charges to be paid by a specified party for a part of a voyage, i.e. up to a specified location.



_10

Origin port charges

Charges payable at the port of origin.



_11

Origin haulage charges

Haulage charges for the pickup of goods at origin.



_12

Other charges



_13

Specific amount payable

Amount that the consignor agrees to be invoiced or to pay. This amount is part of the total charges applied to the consignment.



_14

Transport costs (carriage charges)

Monetary amount calculated on the basis of the transport tariffs or contract eventually including charges or other costs.



_15

All costs up to a specified location

All amounts to be paid by the consignor for a part of the voyage, i.e. up to a location that must be precised. (The remaining part of the voyage to be paid by the consignee) The amounts are calculated by the carrier in accordance with tariffs or in case of special events during the voyage (e.g. rail - freight costs - additional costs).



_16

Weight/valuation charge

Code to indicate weight/valuation charges to be either wholly prepaid or wholly collect.



_17

All costs

Description to be provided.



_18

Transport costs and supplementary costs

Description to be provided.



_19

Supply of certificate of shipment

Charges payable for the supply of a certificate of shipment.



_20

Supply of consular formalities or certificate of origin

Charges payable for the supply of consular formalities or certificate of origin.



_21

Supply of non-categorised documentation in paper form

Charges payable for the supply of one or more documents in paper form that are not otherwise categorised.



_22

Supply of customs formalities, export

Charges payable for the supply of export customs formalities.



_23

Supply of customs formalities, transit

Charges payable for the supply of transit customs formalities.



_24

Supply of customs formalities, import

Charges payable for the supply of import customs formalities.