_5375

Enum _5375 

pub enum _5375 {
Show 28 variants AA, AB, AC, AD, AE, AI, AQ, CA, CT, CU, DI, EC, NW, PC, PE, PK, PL, PT, PU, PV, PW, QT, SR, TB, TU, TW, WH, WI,
}
Price type code

Code specifying the type of price.

Variants



AA

Cancellation price

Price authorized to be charged in the event of an order being cancelled.



AB

Per ton

To indicate that the price applies per ton.



AC

Minimum order price

A code to identify the price when the minimum number is purchased.



AD

Export price

A code to identify a price for the export market.



AE

Range dependent price

A code identifying the price for a specific range of purchase quantities.



AI

Active ingredient

The price is referring to the active ingredient.



AQ

As is quantity

The price is referring to the measured quantity.



CA

Catalogue



CT

Contract



CU

Consumer unit

The price is referring to the consumer unit.



DI

Distributor



EC

ECSC price

Price registered at European Commission Steel and Carbon office (DG III).



NW

Net weight



PC

Price catalogue



PE

Per each



PK

Per kilogram



PL

Per litre



PT

Per tonne



PU

Specified unit



PV

Provisional price



PW

Gross weight



QT

Quoted



SR

Suggested retail



TB

To be negotiated



TU

Traded unit

The price is referring to the traded unit.



TW

Theoretical weight

Weight calculated on ordered dimension (length, width, thickness) not on final dimension (e.g. steel products).



WH

Wholesale



WI

Gross volume

The price is calculated based on gross volume.