_6341

Enum _6341 

pub enum _6341 {
Show 24 variants AAA, AAB, AMS, ARG, AST, AUS, BEL, CAN, CAR, CIE, DEN, ECR, FIN, FRA, IMF, LNF, LNS, MIL, NOR, NYC, PHI, SRE, SWE, ZUR,
}
Exchange rate currency market identifier

To identify an exchange rate currency market.

Variants



AAA

Paris exchange



AAB

Colombian official exchange (Central Bank of Colombia)

The currency exchange rate is set by the Central Bank of Colombia.



AMS

Amsterdam exchange



ARG

Bolsa de Comercio de Buenos Aires

Argentina exchange.



AST

Australian exchange



AUS

Wien exchange

Wiener Boersenkammer.



BEL

Brussels exchange

Commission de la Bourse Bruxelles.



CAN

Toronto exchange



CAR

Contractual agreement exchange rate



CIE

US Customs Information Exchange

Currency rates published by the US Customs Information Exchange, 6 WTC, New York NY 10048-0945, USA.



DEN

Copenhagen exchange

Koebenhavns Fondsboers.



ECR

European Community period exchange rate

Description to be provided.



FIN

Helsinki exchange



FRA

Frankfurt exchange



IMF

International Monetary Fund



LNF

London exchange, first closing



LNS

London exchange, second closing



MIL

Milan exchange



NOR

Oslo exchange



NYC

New York exchange



PHI

Philadelphia exchange



SRE

Specific railway exchange currency

Specific rate of exchange applied to currency exchanges between rail companies and partners.



SWE

Stockholm exchange



ZUR

Zurich exchange