_6343

Enum _6343 

pub enum _6343 {
Show 18 variants _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17, _18,
}
Currency type code qualifier

Code qualifying the type of currency.

Variants



_1

Customs valuation currency

The name or symbol of the monetary unit involved in the transaction for customs valuation.



_2

Insurance currency

The name or symbol of the monetary unit involved in the transaction for insurance purposes.



_3

Home currency

The name or symbol of the local monetary unit.



_4

Invoicing currency

The name or symbol of the monetary unit used for calculation in an invoice.



_5

Account currency

The name or symbol of the monetary unit to be converted from.



_6

Reference currency

The name or symbol of the monetary unit to be converted.



_7

Target currency

The name or symbol of the monetary unit to be converted into.



_8

Price list currency

The name or symbol of the monetary unit used in a price list.



_9

Order currency

The name or symbol of the monetary unit used in an order.



_10

Pricing currency

The name or symbol of the monetary unit used for pricing purposes.



_11

Payment currency

The name or symbol of the monetary unit used for payment.



_12

Quotation currency

The name or symbol of the monetary unit used in a quotation.



_13

Recipient local currency

The name or symbol of the local monetary unit at recipient’s location.



_14

Supplier currency

The name or symbol of the monetary unit normally used by the supplier.



_15

Sender local currency

The name or symbol of the local monetary unit at sender’s location.



_16

Tariff currency

The currency as per tariff.



_17

Charge calculation currency

The currency in which the charges are calculated.



_18

Tax currency

The currency in which tax amounts are due or have been paid.