pub enum _6347 {
_1,
_2,
_3,
_4,
_5,
_6,
_7,
}Expand description
Currency usage code qualifier
Code qualifying the usage of a currency.
Variants
_1
Charge payment currency
The currency in which charges are to be paid.
_2
Reference currency
The currency applicable to amounts stated. It may have to be converted.
_3
Target currency
The currency which should be used to the target destination of the transaction.
_4
Transport document currency
Currency applicable to amounts stated in a transport document/message.
_5
Calculation base currency
Currency on which the calculation is based.
_6
Information Currency
Additional currency the message recipient needs for information purposes. The actual message amount(s) is/are not based upon this currency.
_7
Currency of the account
Currency in which the account is held.