_7085

Enum _7085 

pub enum _7085 {
Show 22 variants _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17, _18, _19, _20, _21, _22,
}
Cargo type classification code

Code specifying the classification of a type of cargo.

Variants



_1

Documents

Printed, typed or written matter including leaflets, pamphlets, certificates etc., which are not subject to import duties and taxes, restrictions and prohibitions.



_2

Low value non-dutiable consignments

Imported consignments/items/goods in respect of which Customs duties and other taxes are waived as they are below a value determined by the Customs administration.



_3

Low value dutiable consignments

Imported consignments/items/goods in respect of which Customs duties and other taxes are payable are below a certain amount as determined by the Customs administration.



_4

High value consignments

Imported consignments/items/goods which are determined as having a value above a certain amount fixed by the Customs administration, which may or may not attract duties and taxes.



_5

Other non-containerized

Non-containerized cargo which cannot be categorized by any of the other nature of cargo code.



_6

Vehicles

Vehicles which are not stowed in containers.



_7

Roll-on roll-off

Cargo transported or to be transported on roll-on roll- off vessels and which is transportable on its own wheels or stowed on special heavy duty trailers.



_8

Palletized

Non-containerized cargo which is palletized.



_9

Containerized

Cargo stowed or to be stowed in a container.



_10

Breakbulk

Non-containerized cargo stowed in vessels’ holds.



_11

Hazardous cargo

Cargo with dangerous properties, according to appropriate dangerous goods regulations.



_12

General cargo

Cargo of a general nature, not otherwise specified.



_13

Liquid cargo

Cargo in liquid form.



_14

Temperature controlled cargo

Cargo transported under specified temperature conditions.



_15

Environmental pollutant cargo

Cargo is an environmental pollutant.



_16

Not-hazardous cargo

Cargo which is not hazardous.



_17

Diplomatic

Cargo transported under diplomatic conditions.



_18

Military

Cargo for military purposes.



_19

Obnoxious

Cargo that is objectionable to human senses.



_20

Out of gauge

Cargo that has at least one non-standard dimension.



_21

Household goods and personal effects

Cargo consisting of household goods and personal effects.



_22

Frozen cargo

Cargo of frozen products.