_7273

Enum _7273 

pub enum _7273 {
Show 60 variants _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17, _18, _19, _20, _21, _22, _23, _24, _25, _26, _27, _28, _29, _30, _31, _32, _33, _34, _35, _36, _37, _38, _39, _40, _41, _42, _43, _44, _45, _46, _47, _48, _49, _50, _51, _52, _53, _54, _55, _56, _57, _58, _59, _60,
}
Service requirement code

Code specifying a service requirement.

Variants



_1

Carrier loads

The cargo is loaded in the equipment by the carrier.



_2

Full loads

Container to be stuffed or stripped under responsibility and for account of the shipper or the consignee.



_3

Less than full loads

Container to be stuffed and stripped for account and risk of the carrier.



_4

Shipper loads

The cargo is loaded in the equipment by the shipper.



_5

To be delivered

The cargo is to be delivered as instructed.



_6

To be kept

The cargo is to be retained awaiting further instructions.



_7

Transhipment allowed

Transhipment of goods is allowed.



_8

Transhipment not allowed

Transhipment of goods is not allowed.



_9

Partial shipment allowed

Partial shipment is allowed.



_10

Partial shipment not allowed

Partial shipment is not allowed.



_11

Partial shipment and/or drawing allowed

Partial shipment and/or drawing is allowed.



_12

Partial shipment and/or drawing not allowed

Partial shipment and/or drawing is not allowed.



_13

Carrier unloads

The cargo is to be unloaded from the equipment by the carrier.



_14

Shipper unloads

The cargo is to be unloaded from the equipment by the shipper.



_15

Consignee unloads

The cargo is to be unloaded from the equipment by the consignee.



_16

Consignee loads

The cargo is to be loaded in the equipment by the consignee.



_17

Exclusive usage of equipment

Usage of the equipment is reserved for exclusive use.



_18

Non exclusive usage of equipment

Usage of the equipment is not reserved for exclusive use.



_19

Direct delivery

Consignment for direct delivery to the consignee.



_20

Direct pick-up

Consignment for direct pick-up from the consignee.



_21

Request for delivery advice services

The service provider is requested to advise about delivery.



_22

Do not arrange customs clearance

Indication that the recipient of the message is not to arrange customs clearance.



_23

Arrange customs clearance

Indication that the recipient of the message is to arrange customs clearance.



_24

Check container condition

Condition of the container is to be checked.



_25

Damaged containers allowed

Damaged containers are allowed.



_26

Dirty containers allowed

Dirty containers are allowed.



_27

Fork lift holes not required

Container needs not to be equipped with pocket holes, but they are allowed.



_28

Fork lift holes required

Container must be equipped with pocket holes.



_29

Insure goods during transport

Indication that the recipient of the message is to insure the goods during transport.



_30

Arrange main-carriage

Indication that the recipient of the message is to arrange the main-carriage.



_31

Arrange on-carriage

Indication that the recipient of the message is to arrange the on-carriage.



_32

Arrange pre-carriage

Indication that the recipient of the message is to arrange the pre-carriage.



_33

Report container safety convention information

Indication that the information on the Container Safety Convention plate (CSC-plate) should be reported.



_34

Check seals

Sealing up of the container is to be checked.



_35

Container must be clean

Container is to be released or delivered clean.



_36

Request for proof of delivery

The service provider is requested to provide proof of delivery.



_37

Request for Customs procedure

The service provider is requested to perform Customs procedure.



_38

Request for administration services

The service provider is requested to perform administration services.



_39

Transport insulated under Intercontainer INTERFRIGO conditions

Insulated transport under Intercontainer INTERFRIGO (joint European railways agreement) conditions.



_40

Transport mechanically refrigerated under Intercontainer INTERFRIGO conditions

Mechanically refrigerated transport under Intercontainer INTERFRIGO (joint European railways agreement) conditions.



_41

Cool or freeze service, not under Intercontainer INTERFRIGO conditions

Cool or freeze service not under Intercontainer INTERFRIGO (joint European railways agreement) conditions.



_42

Transhipment overseas

Transport equipment is to be transferred overseas.



_43

Station delivery

The specified equipment destination station is also the place of delivery of the goods.



_44

Non station delivery

The specified equipment destination station is not the place of delivery of the goods.



_45

Cleaning or disinfecting

The service required is cleaning or disinfection.



_46

Close ventilation valve

The ventilation valve of the equipment must be closed.



_47

Consignment held for pick-up

The consignment is to be held until it is picked up.



_48

Refrigeration unit check

Refrigeration unit has to be checked.



_49

Customs clearance at arrival country by carrier

The carrier is to arrange customs clearance in the arrival country.



_50

Customs clearance at departure country by carrier

The carrier is to arrange customs clearance in the departure country.



_51

Heating for live animals

Heating for live animals has to be provided.



_52

Goods humidification

Humidification of the goods has to be performed.



_53

Ensure load is secure

The load must be checked for correct stowage.



_54

Open ventilation valve

The ventilation valve of the equipment must be opened.



_55

Phytosanitary control

Phytosanitary control to be performed.



_56

Tare check by carrier

Carrier must check the tare of the equipment and attached items.



_57

Temperature check

The temperature must be checked.



_58

Weighing of goods

The goods have to be weighed.



_59

Escort

An escort is required.



_60

No escort

An escort is not required.