pub struct BGM {
pub _010: Option<C002>,
pub _020: Option<C106>,
pub _030: Option<_1225>,
pub _040: Option<_4343>,
}Expand description
BGM - BEGINNING OF MESSAGE
A segment indicating the beginning of a message and identifying the consignment for which status is being reported.
Fields
_010: Option<C002>_020: Option<C106>_030: Option<_1225>_040: Option<_4343>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for BGM
impl<'de> Deserialize<'de> for BGM
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more