pub struct C100 {
pub _010: Option<_4053>,
pub _020: Option<_1131>,
pub _030: Option<_3055>,
pub _040: Option<String>,
pub _050: Option<String>,
}Expand description
Terms of delivery or transport
Terms of delivery or transport code from a specified source.
Fields
_010: Option<_4053>Delivery or transport terms description code
Code specifying the delivery or transport terms. 1 Use UN/ECE Recommendation No. 5 Incoterms 1990. If not applicable, use appropriate code set in combination with 1131/3055.
_020: Option<_1131>Code list identification code
Code identifying a code list.
_030: Option<_3055>Code list responsible agency code
Code specifying the agency responsible for a code list.
_040: Option<String>Delivery or transport terms description
Free form description of delivery or transport terms.
_050: Option<String>Delivery or transport terms description
Free form description of delivery or transport terms.