pub struct C200 {
pub _010: Option<String>,
pub _020: Option<_1131>,
pub _030: Option<_3055>,
pub _040: Option<String>,
pub _050: Option<_4237>,
pub _060: Option<String>,
}Expand description
C200 Charge
Identification of a charge by code and/or by name.
Fields
_010: Option<String>Freight and other charges description identifier
Code identifying freight and other charges. 1 Use UN/ECE Recommendation No. 2 Freight costs and charges. If not applicable, use appropriate code in combination with 1131/3055.
_020: Option<_1131>Code list identification code
Code identifying a code list.
_030: Option<_3055>Code list responsible agency code
Code specifying the agency responsible for a code list.
_040: Option<String>Freight and other charges description
Free form description of freight and other charges.
_050: Option<_4237>Payment arrangement code
Code specifying the arrangements for a payment.
_060: Option<String>Item identifier
To identify an item.