pub struct C203 {
pub _010: _5243,
pub _020: Option<_1131>,
pub _030: Option<_3055>,
pub _040: Option<String>,
pub _050: Option<String>,
pub _060: Option<_1131>,
pub _070: Option<_3055>,
pub _080: Option<String>,
pub _090: Option<_1131>,
pub _100: Option<_3055>,
}Expand description
C203 Rate/tariff class
Identification of the applicable rate/tariff class.
Fields
_010: _5243Rate or tariff class description code
Code specifying an applicable rate or tariff class. 1 User or association defined code. May be used in combination with 1131/3055.
_020: Option<_1131>Code list identification code
Code identifying a code list.
_030: Option<_3055>Code list responsible agency code
Code specifying the agency responsible for a code list.
_040: Option<String>Rate or tariff class description
Free form description of an applicable rate or tariff class.
_050: Option<String>Supplementary rate or tariff code
Code specifying a supplementary rate or tariff. 1 User or association defined code. May be used in combination with 1131/3055.
_060: Option<_1131>Code list identification code
Code identifying a code list.
_070: Option<_3055>Code list responsible agency code
Code specifying the agency responsible for a code list.
_080: Option<String>Supplementary rate or tariff code
Code specifying a supplementary rate or tariff. 1 User or association defined code. May be used in combination with 1131/3055.
_090: Option<_1131>Code list identification code
Code identifying a code list.
_100: Option<_3055>Code list responsible agency code
Code specifying the agency responsible for a code list.