pub struct C229 {
pub _010: _5237,
pub _020: Option<_1131>,
pub _030: Option<_3055>,
}Expand description
C229 Charge category
Identification of a category or a zone of charges.
Fields
_010: _5237Charge category code
Code specifying the category of charges. 1 User or association defined code. May be used in combination with 1131/3055.
_020: Option<_1131>Code list identification code
Code identifying a code list.
_030: Option<_3055>Code list responsible agency code
Code specifying the agency responsible for a code list.