pub struct C232 {
pub _010: Option<String>,
pub _020: Option<String>,
pub _030: Option<String>,
pub _040: Option<String>,
}Expand description
C232 Government action
Code indicating a type of government action.
Fields
_010: Option<String>Government agency identification code
Code identifying a government agency.
_020: Option<String>Government involvement code
Code indicating the requirement and status of governmental involvement.
_030: Option<String>Government action code
Code specifying a type of government action such as inspection, detention, fumigation, security.
_040: Option<String>Government procedure code
Code specifying a government procedure.