pub struct C501 {
pub _010: String,
pub _020: Option<String>,
pub _030: Option<String>,
pub _040: Option<String>,
pub _050: Option<String>,
}Expand description
C501 Percentage details
Identification of measurement type.
Fields
_010: StringPercentage type code qualifier C an..3
Code qualifying the type of percentage.
_020: Option<String>Percentage C an..10
To specify a percentage.
_030: Option<String>Percentage basis identification code C an..3
Code specifying the basis on which a percentage is calculated.
1 User or association defined code. May be used in combination with 1131/3055.
_040: Option<String>Code list identification code C an..17
Code identifying a code list.
_050: Option<String>Code list responsible agency code C an..3
Code specifying the agency responsible for a code list.