pub struct C528 {
pub _010: Option<String>,
pub _020: Option<_1131>,
pub _030: Option<_3055>,
}Expand description
C528 Commodity/rate detail
Identification of commodity/rates.
Fields
_010: Option<String>Commodity identification code
Code identifying a commodity for Customs, transport or statistical purposes (generic term). 1 User or association defined code. May be used in combination with 1131/3055.
_020: Option<_1131>Code list identification code
Code identifying a code list.
_030: Option<_3055>Code list responsible agency code
Code specifying the agency responsible for a code list.