pub struct C827 {
pub _010: String,
pub _020: Option<String>,
pub _030: Option<String>,
}Expand description
C827 - TYPE OF MARKING
Specification of the type of marking that reflects the method that was used and the conventions adhered to for marking (e.g. of packages).
Fields
_010: StringMarking type code M an..3
_020: Option<String>Code list identification code C an..17
_030: Option<String>Code list responsible agency code C an..3