pub struct CNI {
pub _010: Option<String>,
pub _020: Option<C503>,
pub _030: Option<String>,
}Expand description
CNI - CONSIGNMENT INFORMATION
A segment to identify a consignment for which status details are given.
Fields
_010: Option<String>CONSOLIDATION ITEM NUMBER
To specify a consignment within a consolidation.
_020: Option<C503>C503 - DOCUMENT/MESSAGE DETAILS
Identification of document/message by number, status, source and/or language.
_030: Option<String>CONSIGNMENT LOAD SEQUENCE IDENTIFIER
To identify the loading sequence of a consignment or consignments.