pub struct CUX {
pub _010: Option<C504>,
pub _020: Option<C504>,
pub _030: Option<String>,
pub _040: Option<_6341>,
}Expand description
Currencies
A segment to specify a contact name associated with the party.
Fields
_010: Option<C504>Currency details
The usage to which a currency relates.
_020: Option<C504>Currency details
The usage to which a currency relates.
_030: Option<String>Currency exchange rate
To specify the rate at which one specified currency is expressed in another specified currency.
_040: Option<_6341>Exchange rate currency market identifier
To identify an exchange rate currency market.