pub struct DOC {
pub _010: Option<C002>,
pub _020: Option<C503>,
pub _030: Option<String>,
pub _040: Option<String>,
pub _050: Option<String>,
}Expand description
DOC - DOCUMENT/MESSAGE DETAILS
A segment to specify document details related to the status code, such as indication which document is missing (status code: document missing).
Fields
_010: Option<C002>C002 - DOCUMENT/MESSAGE NAME
Identification of a type of document/message by code or name. Code preferred.
_020: Option<C503>C503 - DOCUMENT/MESSAGE DETAILS
Identification of document/message by number, status, source and/or language.
_030: Option<String>COMMUNICATION MEDIUM TYPE CODE
Code specifying the type of communication medium.
_040: Option<String>DOCUMENT COPIES REQUIRED QUANTITY
Quantity of document copies required.
_050: Option<String>DOCUMENT ORIGINALS REQUIRED QUANTITY
Quantity of document originals required.