Struct edifact_types::d00b::Eqd
source · pub struct Eqd {
pub _010: String,
pub _020: Option<C237>,
pub _030: Option<C224>,
pub _040: Option<String>,
pub _050: Option<String>,
pub _060: Option<String>,
}Expand description
EQD - EQUIPMENT DETAILS
A segment identifying equipment related to status or event such as a container of a multi-container consignment.
Fields
_010: StringEQUIPMENT TYPE CODE QUALIFIER
Code qualifying a type of equipment.
_020: Option<C237>C237 - EQUIPMENT IDENTIFICATION
Marks (letters/numbers) identifying equipment.
_030: Option<C224>C224 - EQUIPMENT SIZE AND TYPE
Code and or name identifying size and type of equipment. Code preferred.
_040: Option<String>EQUIPMENT SUPPLIER CODE
Code specifying the party that is the supplier of the equipment.
_050: Option<String>EQUIPMENT STATUS CODE
Code specifying the status of equipment.
_060: Option<String>FULL OR EMPTY INDICATOR CODE
Code indicating whether an object is full or empty.