Struct edifact_types::d00b::Ftx
source · pub struct Ftx {
pub _010: String,
pub _020: Option<String>,
pub _030: Option<C107>,
pub _040: Option<C108>,
pub _050: Option<String>,
pub _060: Option<String>,
}Expand description
FTX - FREE TEXT
A segment specifying free form or processable supplementary or other information.
Fields
_010: StringTEXT SUBJECT CODE QUALIFIER
Code qualifying the subject of the text.
_020: Option<String>FREE TEXT FUNCTION CODE
Code specifying the function of free text.
_030: Option<C107>TEXT REFERENCE
Coded reference to a standard text and its source.
_040: Option<C108>TEXT LITERAL
Free text; one to five lines.
_050: Option<String>LANGUAGE NAME CODE
Code specifying the language name.
_060: Option<String>FREE TEXT FORMAT CODE
Code specifying the format of free text.