pub struct GIN {
pub _010: String,
pub _020: C208,
pub _030: Option<C208>,
pub _040: Option<C208>,
pub _050: Option<C208>,
pub _060: Option<C208>,
}Expand description
GIN - GOODS IDENTITY NUMBER
A segment specifying identity numbers related to the transport line items.
Fields
_010: StringOBJECT IDENTIFICATION CODE QUALIFIER
Code qualifying the identification of an object.
_020: C208C208 - IDENTITY NUMBER RANGE
Goods item identification numbers, start and end of consecutively numbered range.
_030: Option<C208>C208 - IDENTITY NUMBER RANGE
Goods item identification numbers, start and end of consecutively numbered range.
_040: Option<C208>C208 - IDENTITY NUMBER RANGE
Goods item identification numbers, start and end of consecutively numbered range.
_050: Option<C208>C208 - IDENTITY NUMBER RANGE
Goods item identification numbers, start and end of consecutively numbered range.
_060: Option<C208>C208 - IDENTITY NUMBER RANGE
Goods item identification numbers, start and end of consecutively numbered range.