pub struct GOR {
pub _010: Option<String>,
pub _020: Option<C232>,
pub _030: Option<C232>,
pub _040: Option<C232>,
pub _050: Option<C232>,
}Expand description
GOR Governmental requirements
To indicate the requirement for a specific governmental action and/or procedure or which specific procedure is valid for a specific part of the transport.
Fields
_010: Option<String>Transport movement code
Code specifying the transport movement.
_020: Option<C232>C232 Government action
Code indicating a type of government action.
_030: Option<C232>C232 Government action
Code indicating a type of government action.
_040: Option<C232>C232 Government action
Code indicating a type of government action.
_050: Option<C232>C232 Government action
Code indicating a type of government action.