pub struct Interchange<T>where
T: Display,{
pub una: Option<UNA>,
pub unb: UNB,
pub segment: T,
pub unz: UNZ,
}Expand description
from: official info 6.1 Interchange structure
The Service String Advice, UNA, and the service segments UNB to UNZ shall appear in the below stated order in an interchange. There may be several functional groups or messages within an interchange and several messages in a functional group. A message consists of segments. The structures for segments and for data elements therein are shown in 6.2 and 6.3. The contents of the service segments are shown annex B. See also figure 1.
An interchange consists of:
| x | x | x | x | Name | Abbr. | Req. |
|---|---|---|---|---|---|---|
| o | o | o | o | Service String Advice | UNA | Conditional |
| _ | _ | _ | _ | Interchange Header | UNB | Mandatory |
| | | _ | _ | _ | Functional Group Header | UNG | Conditional |
| | | | | _ | _ | Message Header | UNH | Mandatory |
| | | | | | | User Data Segments | As required | ||
| | | | | | | _ | Message Trailer | UNT | Mandatory |
| | | | | _ | _ | Functional Group Trailer | UNE | Conditional |
| | | _ | _ | _ | Interchange Trailer | UNZ | Mandatory |
In addition to the above service segments, the service segment UNS can, when required, be used to divide a message into sections. See annex B (NOT IMPLEMENTED).
Fields
una: Option<UNA>unb: UNBsegment: Tunz: UNZTrait Implementations
Sourceimpl<T> Clone for Interchange<T>
impl<T> Clone for Interchange<T>
Sourcefn clone(&self) -> Interchange<T>
fn clone(&self) -> Interchange<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T> Debug for Interchange<T>
impl<T> Debug for Interchange<T>
Sourceimpl<T> Default for Interchange<T>
impl<T> Default for Interchange<T>
Sourcefn default() -> Interchange<T>
fn default() -> Interchange<T>
Returns the “default value” for a type. Read more
Sourceimpl<'de, T> Deserialize<'de> for Interchange<T>where
T: Display + Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Interchange<T>where
T: Display + Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> Display for Interchange<T>where
T: Display,
impl<T> Display for Interchange<T>where
T: Display,
Sourceimpl<'a, T: Default + Parser<&'a str, T, Error<&'a str>> + Display> Parser<&'a str, Interchange<T>, Error<&'a str>> for Interchange<T>
impl<'a, T: Default + Parser<&'a str, T, Error<&'a str>> + Display> Parser<&'a str, Interchange<T>, Error<&'a str>> for Interchange<T>
Sourceimpl<T> PartialEq for Interchange<T>
impl<T> PartialEq for Interchange<T>
Sourceimpl<T> Serialize for Interchange<T>
impl<T> Serialize for Interchange<T>
impl<T> Eq for Interchange<T>
impl<T> StructuralPartialEq for Interchange<T>where
T: Display,