Struct edifact_types::d00b::Loc
source · pub struct Loc {
pub _010: String,
pub _020: Option<C517>,
pub _030: Option<C519>,
pub _040: Option<C553>,
pub _050: Option<String>,
}Expand description
LOC - PLACE/LOCATION IDENTIFICATION
A segment identifying a place/location which applies to the consignment such as consignment origin and destination.
Fields
_010: StringLOCATION FUNCTION CODE QUALIFIER
Code identifying the function of a location.
_020: Option<C517>LOCATION IDENTIFICATION
Identification of a location by code or name.
_030: Option<C519>RELATED LOCATION ONE IDENTIFICATION
Identification the first related location by code or name.
_040: Option<C553>RELATED LOCATION TWO IDENTIFICATION
Identification of second related location by code or name.
_050: Option<String>RELATION CODE
Code specifying a relation.