pub struct MEA {
pub _010: String,
pub _020: Option<C502>,
pub _030: Option<C174>,
pub _040: Option<String>,
}Expand description
MEA - MEASUREMENTS
A segment specifying measurements, other than dimension, of a goods item.
Fields
_010: StringMEASUREMENT PURPOSE CODE QUALIFIER
Code qualifying the purpose of the measurement.
_020: Option<C502>C502 - MEASUREMENT DETAILS
Identification of measurement type.
_030: Option<C174>C174 - VALUE/RANGE
Measurement value and relevant minimum and maximum values of the measurement range.
_040: Option<String>SURFACE OR LAYER CODE
Code specifying the surface or layer of an object.