NAD

Struct NAD 

pub struct NAD {
    pub _010: _3035,
    pub _020: Option<C082>,
    pub _030: Option<C058>,
    pub _040: Option<C080>,
    pub _050: Option<C059>,
    pub _060: Option<String>,
    pub _070: Option<C819>,
    pub _080: Option<String>,
    pub _090: Option<String>,
}
NAD - NAME AND ADDRESS

A segment specifying the name and/or address associated with the event such as notify party, terminal address, trucking company for gate move.

Fields

_010: _3035

PARTY FUNCTION CODE QUALIFIER

Code giving specific meaning to a party.

_020: Option<C082>

C082 - PARTY IDENTIFICATION DETAILS

Identification of a transaction party by code.

_030: Option<C058>

C058 - NAME AND ADDRESS

Unstructured name and address: one to five lines.

_040: Option<C080>

C080 - PARTY NAME

Identification of a transaction party by name, one to five lines. Party name may be formatted.

_050: Option<C059>

C059 - STREET

Street address and/or PO Box number in a structured address: one to four lines.

_060: Option<String>

CITY NAME

Name of a city.

_070: Option<C819>

C819 - COUNTRY SUB-ENTITY DETAILS

To specify a part of a country (eg county or part of a city).

_080: Option<String>

POSTAL IDENTIFICATION CODE

Code specifying the postal zone or address.

_090: Option<String>

COUNTRY NAME CODE

Identification of the name of the country or other geographical entity as specified in ISO 3166.