PCI

Struct PCI 

pub struct PCI {
    pub _010: Option<String>,
    pub _020: Option<C210>,
    pub _030: Option<String>,
    pub _040: Option<C827>,
}
PCI - PACKAGE IDENTIFICATION

A segment specifying marks related to the transport line items.

Fields

_010: Option<String>

MARKING INSTRUCTIONS CODE

Code specifying instructions for marking.

_020: Option<C210>

C210 - MARKS & LABELS

Shipping marks on packages in free text; one to ten lines.

_030: Option<String>

CONTAINER OR PACKAGE CONTENTS INDICATOR CODE

Code indicating the contents of container or package.

_040: Option<C827>

C827 - TYPE OF MARKING

Specification of the type of marking that reflects the method that was used and the conventions adhered to for marking (e.g. of packages).