S002

Struct S002 

pub struct S002 {
    pub _010: String,
    pub _020: Option<_0007>,
    pub _030: Option<String>,
}
Interchange sender

Identification of the sender of the interchange.

Fields

_010: String

Sender identification

Name or coded representation of the sender of a data interchange. Code or name as specified in IA.

_020: Option<_0007>_030: Option<String>

Address for reverse routing

Address specified by the sender of an interchange to be included by the recipient in the response interchanges to facilitate internal routing.