S003

Struct S003 

pub struct S003 {
    pub _010: String,
    pub _020: Option<_0007>,
    pub _030: Option<String>,
}
Interchange recipient

Identification of the recipient of the interchange.

Fields

_010: String

Recipient identification

Name or coded representation of the recipient of a data interchange. Code or name as specified in IA.

_020: Option<_0007>_030: Option<String>

Routing address

Address specified by the recipient of an interchange to be included by the sender and used by the recipient for routing of received interchanges inside his organization. If used, normally coded sub-address for onward routing.