pub struct S004 {
pub _010: String,
pub _020: String,
}Expand description
Date/time of preparation
Date/time of preparation of the interchange.
Fields
_010: StringDate of preparation
Local date when an interchange or a functional group was prepared. YYMMDD
_020: StringTime of preparation
Local time of day when an interchange or a functional group was prepared. HHMM