pub struct S017 {
pub _010: String,
pub _020: Option<String>,
pub _030: Option<String>,
pub _040: Option<String>,
}Fields
_010: StringMessage implementation guideline identification
Coded identification of the message implementation guideline, assigned by its controlling agency.
_020: Option<String>Message implementation guideline version number
Version number of the message implementation guideline.
_030: Option<String>Message implementation guideline release number
Release number within the message implementation guideline version number.
_040: Option<String>Controlling agency, coded
Code identifying a controlling agency.