Struct edifact_types::d00b::Sel
source · pub struct Sel {
pub _010: Option<String>,
pub _020: Option<C215>,
pub _030: Option<String>,
pub _040: Option<C208>,
}Expand description
SEL - SEAL NUMBER
A segment identifying seal and seal issuer associated with the equipment.
Fields
_010: Option<String>SEAL IDENTIFIER
To identify a seal.
_020: Option<C215>SEAL ISSUER
Identification of the issuer of a seal on equipment either by code or by name.
_030: Option<String>SEAL CONDITION CODE
Code specifying the condition of a seal.
_040: Option<C208>C208 - IDENTITY NUMBER RANGE
Goods item identification numbers, start and end of consecutively numbered range.