pub struct TDT {
pub _010: String,
pub _020: Option<String>,
pub _030: Option<C220>,
pub _040: Option<C228>,
pub _050: Option<C040>,
pub _060: Option<String>,
pub _070: Option<C401>,
pub _080: Option<C222>,
pub _090: Option<String>,
}Expand description
TDT - DETAILS OF TRANSPORT
A segment identifying conveyance related to the status or event such as flight, vessel/voyage.
Fields
_010: StringTRANSPORT STAGE CODE QUALIFIER
Code qualifying a specific stage of transport.
_020: Option<String>MEANS OF TRANSPORT JOURNEY IDENTIFIER
To identify a journey of a means of transport.
_030: Option<C220>C220 - MODE OF TRANSPORT
Method of transport code or name. Code preferred.
_040: Option<C228>C228- TRANSPORT MEANS
Code and/or name identifying the type of means of transport.
_050: Option<C040>C040 - CARRIER
Identification of a carrier by code and/or by name. Code preferred.
_060: Option<String>TRANSIT DIRECTION INDICATOR CODE
Code specifying the direction of transport.
_070: Option<C401>C401 - EXCESS TRANSPORTATION INFORMATION
To provide details of reason for, and responsibility for, use of transportation other than normally utilized.
_080: Option<C222>C222 - TRANSPORT IDENTIFICATION
Code and/or name identifying the means of transport.
_090: Option<String>TRANSPORT MEANS OWNERSHIP INDICATOR CODE
Code indicating the ownership of a means of transport.