pub struct TMD {
pub _010: Option<C219>,
pub _020: Option<String>,
pub _030: Option<String>,
}Expand description
TMD - TRANSPORT MOVEMENT DETAILS
A segment to specify transport movement details related to the equipment.
Fields
_010: Option<C219>C219 - MOVEMENT TYPE
Description of type of service for movement of cargo.
_020: Option<String>EQUIPMENT PLAN DESCRIPTION
Free form description of the equipment plan.
_030: Option<String>HAULAGE ARRANGEMENTS CODE
Code specifying the arrangement for the haulage of goods.