pub struct TPL {
pub _010: C222,
}Expand description
TPL - TRANSPORT PLACEMENT
A segment to identify the means of transport to which the equipment is linked, necessary in cases where this forms the key to retrieve relevant information.
Fields
_010: C222C222 - TRANSPORT IDENTIFICATION
Code and/or name identifying the means of transport.