pub struct TSR {
pub _010: Option<C536>,
pub _020: Option<C233>,
pub _030: Option<C537>,
pub _040: Option<C703>,
}Expand description
TSR - TRANSPORT SERVICE REQUIREMENTS
A segment identifying the transport service relating to the consignment.
Fields
_010: Option<C536>CONTRACT AND CARRIAGE CONDITION
To identify a contract and carriage condition.
_020: Option<C233>SERVICE
To identify a service (which may constitute an additional component to a basic contract).
_030: Option<C537>TRANSPORT PRIORITY
To indicate the priority of requested transport service.
_040: Option<C703>NATURE OF CARGO
Rough classification of a type of cargo.