UNA

Struct UNA 

pub struct UNA {
    pub component_data_element_seperator: char,
    pub data_element_seperator: char,
    pub decimal_notation: char,
    pub release_indicator: char,
    pub reserved_for_future_use: char,
    pub segment_terminator: char,
}
UNA, Service String advice

Function: To define the characters selected for use as delimiters and indicators in the rest of the interchange that follows:

The specifications in the Service string advice take precedence over the specifications for delimiters etc. in segment UNB. See clause 4.

When transmitted, the Service string advice must appear immediately before the Interchange Header (UNB) segment and begin with the upper case characters UNA immediately followed by the six characters selected by the sender to indicate, in sequence, the following functions: Repr. | Req. | Name | Remarks — | — | — | — an1 | M | COMPONENT DATA ELEMENT SEPARATOR | an1 | M | DATA ELEMENT SEPARATOR | an1 | M | DECIMAL NOTATION | Comma or full stop an1 | M | RELEASE INDICATOR | If not used, insert space character an1 | M | Reserved for future use | Insert space character an1 | M | SEGMENT TERMINATOR |

Fields

component_data_element_seperator: char

an1 M COMPONENT DATA ELEMENT SEPARATOR

data_element_seperator: char

an1 M DATA ELEMENT SEPARATOR

decimal_notation: char

an1 M DECIMAL NOTATION Comma or full stop

release_indicator: char

an1 M RELEASE INDICATOR If not used, insert space character

reserved_for_future_use: char

an1 M Reserved for future use Insert space character

segment_terminator: char

an1 M SEGMENT TERMINATOR