Enum _0001 Copy item path Source pub enum _0001 {
UNOA,
UNOB,
UNOC,
UNOD,
UNOE,
UNOF,
}Expand description Syntax identifier
Coded identification of the agency controlling a syntax and syntax level used in an interchange.
UN/ECE level A
As defined in the basic code table of ISO 646 with the exceptions of lower case letters, alternative graphic character allocations and national or application-oriented graphic character allocations.
UN/ECE level B
As defined in the basic code table of ISO 646 with the exceptions of alternative graphic character allocations and national or application-oriented graphic character allocations.
UN/ECE level C
As defined in ISO 8859-1 : Information processing - Part 1: Latin alphabet No. 1.
UN/ECE level D
As defined in ISO 8859-2 : Information processing - Part 2: Latin alphabet No. 2.
UN/ECE level E
As defined in ISO 8859-5 : Information processing - Part 5: Latin/Cyrillic alphabet.
UN/ECE level F
As defined in ISO 8859-7 : Information processing - Part 7: Latin/Greek alphabet.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Returns the “default value” for a type.
Read more Deserialize this value from the given Serde deserializer.
Read more Formats the value using the given formatter.
Read more The associated error which can be returned from parsing.
Parses a string
s to return a value of this type.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.