pub enum _1225 {
Show 53 variants
_1,
_2,
_3,
_4,
_5,
_6,
_7,
_8,
_9,
_10,
_11,
_12,
_13,
_14,
_15,
_16,
_17,
_18,
_19,
_20,
_21,
_22,
_23,
_24,
_25,
_26,
_27,
_28,
_29,
_30,
_31,
_32,
_33,
_34,
_35,
_36,
_37,
_38,
_39,
_40,
_41,
_42,
_43,
_44,
_45,
_46,
_47,
_48,
_49,
_50,
_51,
_52,
_53,
}Expand description
1225 Message function code
Variants
_1
Cancellation
Message cancelling a previous transmission for a given transaction.
_2
Addition
_3
Deletion
_4
Change
_5
Replace
_6
_7
_8
_9
_10
_11
_12
_13
_14
_15
_16
_17
_18
_19
_20
_21
_22
_23
_24
_25
_26
_27
_28
_29
_30
_31
_32
_33
_34
_35
_36
_37
_38
_39
_40
_41
_42
_43
_44
_45
_46
_47
_48
_49
_50
_51
_52
_53
53 Test
Code indicating the message is to be considered as a test.