Interchange

Struct Interchange 

pub struct Interchange<T>
where T: Display,
{ pub una: Option<UNA>, pub unb: UNB, pub segment: T, pub unz: UNZ, }
from: official info 6.1 Interchange structure

The Service String Advice, UNA, and the service segments UNB to UNZ shall appear in the below stated order in an interchange. There may be several functional groups or messages within an interchange and several messages in a functional group. A message consists of segments. The structures for segments and for data elements therein are shown in 6.2 and 6.3. The contents of the service segments are shown annex B. See also figure 1.

An interchange consists of:

xxxxNameAbbr.Req.
ooooService String AdviceUNAConditional
____Interchange HeaderUNBMandatory
|___Functional Group HeaderUNGConditional
||__Message HeaderUNHMandatory
|||User Data SegmentsAs required
|||_Message TrailerUNTMandatory
||__Functional Group TrailerUNEConditional
|___Interchange TrailerUNZMandatory

In addition to the above service segments, the service segment UNS can, when required, be used to divide a message into sections. See annex B (NOT IMPLEMENTED).

Fields

una: Option<UNA>unb: UNBsegment: Tunz: UNZ