pub struct S001 {
pub _010: _0001,
pub _020: _0002,
}Expand description
Syntax identifier
Identification of the agency controlling the syntax and indication of syntax level, plus the syntax version number.
Fields
_010: _0001_020: _0002Trait Implementations
Sourceimpl<'de> Deserialize<'de> for S001
impl<'de> Deserialize<'de> for S001
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for S001
impl StructuralPartialEq for S001