pub struct S005 {
pub _010: String,
pub _020: Option<_0025>,
}Expand description
Recipient’s reference, password
Reference or password as agreed between the communicating partners.
Fields
_010: StringRecipient’s reference/password
Unique reference assigned by the recipient to the data interchange or a password to the recipient’s system or to a third party network as specified in the partners interchange agreement. As specified in IA. May be password to recipient’s system or to third party network.
_020: Option<_0025>Recipient’s reference/password qualifier
Qualifier for the recipient’s reference or password. Used if specified in IA.