Struct edifact_types::d95b::Tdt

source ·
pub struct Tdt {
    pub _010: String,
    pub _020: String,
    pub _030: C220,
    pub _040: C228,
    pub _050: C040,
    pub _060: String,
    pub _070: C401,
    pub _080: C222,
    pub _090: String,
}
TDT - DETAILS OF TRANSPORT

To specify the transport details such as mode of transport, means of transport, its conveyance reference number and the identification of the means of transport. The segment may be pointed to by the TPL segment.

Fields

_010: String_020: String_030: C220_040: C228_050: C040_060: String_070: C401_080: C222_090: String