pub enum _1131 {
Show 247 variants
_1,
_2,
_3,
_4,
_5,
_6,
_7,
_8,
_9,
_10,
_11,
_12,
_13,
_14,
_15,
_16,
_17,
_18,
_19,
_20,
_21,
_22,
_23,
_24,
_25,
_26,
_27,
_33,
_34,
_35,
_36,
_37,
_38,
_39,
_40,
_42,
_43,
_44,
_45,
_46,
_47,
_48,
_49,
_52,
_53,
_54,
_55,
_56,
_57,
_58,
_59,
_60,
_61,
_62,
_63,
_64,
_65,
_67,
_68,
_69,
_70,
_71,
_72,
_73,
_74,
_75,
_76,
_77,
_78,
_79,
_80,
_81,
_82,
_83,
_84,
_85,
_86,
_100,
_101,
_102,
_103,
_104,
_105,
_106,
_107,
_108,
_109,
_110,
_112,
_113,
_114,
_115,
_116,
_117,
_118,
_119,
_120,
_121,
_122,
_123,
_125,
_126,
_127,
_128,
_129,
_130,
_131,
_132,
_133,
_134,
_135,
_136,
_137,
_139,
_140,
_141,
_142,
_143,
_144,
_145,
_146,
_147,
_148,
_149,
_150,
_151,
_152,
_153,
_154,
_155,
_156,
_157,
_158,
_160,
_161,
_162,
_163,
_164,
_165,
_166,
_167,
_168,
_169,
_170,
_172,
_173,
_174,
_175,
_176,
_177,
_178,
_179,
_180,
_181,
_182,
_183,
_184,
_185,
_186,
_187,
_188,
_189,
_190,
_191,
_192,
_193,
_194,
_195,
_196,
_197,
_198,
_199,
_200,
_201,
_202,
_203,
_204,
_205,
_206,
_207,
_208,
_209,
_210,
_211,
_212,
_213,
_214,
_215,
_216,
_217,
_218,
_219,
_220,
_221,
_222,
_223,
_224,
_225,
_226,
_227,
_228,
_229,
_230,
_231,
_232,
_233,
_234,
_235,
_236,
_237,
_238,
_239,
_240,
_241,
_242,
_243,
_244,
_245,
_246,
_247,
_248,
_249,
_250,
_251,
_252,
_253,
_254,
_255,
_256,
_257,
_258,
_259,
_260,
_261,
_262,
_263,
_264,
_265,
_266,
_267,
_268,
_269,
_270,
_271,
_272,
_273,
_ZZZ,
}Expand description
Code list identification code
Code identifying a code list.
Variants
_1
Logistics code list
Code list containing logistics and program management activities.
_2
ICD 9
A code list containing the International Classification of Diseases, version 9 (ICD 9).
_3
Operating status
Code list identifying operating status of an entity.
_4
DoDAAC (Department of Defense Activity Address Code)
A code list containing codes assigned to operating military units to identify the name and address of the unit.
_5
Facility identification
A code list identifying a facility(ies).
_6
Application acknowledgement and error codes
A code list to identify acknowledgement and error codes applicable at the application level.
_7
Health industry organization identification
List of codes identifying organizations in the health care industry.
_8
Electromagnetic transmitter identification
A code list containing electromagnetic transmitter identifications.
_9
Military Assistance Program Address Code (MAPAC)
Lists of codes identifying name and address information for organizations participating in a military assistance program.
_10
Medicare provider
A list of codes identifying health care providers under the Medicare program.
_11
Medicaid provider
A list of codes identifying health care providers under a Medicaid program.
_12
Telephone directory
_13
Employee identification
A list of codes identifying employees of an organization.
_14
Sample extraction location
Code list identifying the location from which a sample is taken.
_15
Medical benefits schedule
Code list containing classifications of medical services for use in determining the medical benefits payable.
_16
Postcode directory
[3251] Code defining postal zones or addresses.
_17
ICD 10
Code list containing the International Classification of Diseases, version 10 (ICD 10).
_18
Diagnosis Related Group (DRG)
Code list containing diagnosis related group classifications.
_19
Standard text clauses
A list of codes representing standardized text clauses.
_20
United Nations Standard Products and Services Classification (UN/SPSC) code
A code list that provides a hierarchical classification of goods and services for the purposes of resource discovery and spend analysis.
_21
Policy on claim indicator Identifies a code list containing indicators referring to policy on claims.
(legal persons, partnerships, sole proprietorships and their branch offices) and private persons.
_22
A code list specifying codes assigned by the EDI Registration Authority to register organizations
EDIRA-Id (EDI Registration Authority Identification)
_23
Clearing house automated payment
_24
Rail handling restrictions and instructions
A code list specifying rail codes for handling restrictions or instructions.
_25
Bank identification
Code for identification of banks.
_26
Rail harmonized equipment type
A code list specifying codes for harmonized equipment type in the railway industry.
_27
Railway frontier and transit point
A code list specifying frontier or transit points in the railway industry.
_33
Commercial And Government Entity (CAGE)
List of codes identifying a commercial and government entity.
_34
Reinsurance policy attributes
A list of attributes regarding policies reinsured with a professional reinsurer.
_35
Rail additional charges
A code list identifying specific rail charges included in the payment conditions in addition to the freight cost.
_36
Railway company network
A code list identifying the different railway companies as member of the International Union of Railways.
_37
Railway locations
Code identifying a location in railway environment.
_38
Railway customer
A code list identifying rail customers.
_39
Rail unified nomenclature of goods
_40
Reinsurance monetary type
Identifies the type of reinsurance amounts.
_42
Business function
_43
Clearing House Interbank Payment System Participants ID
Participants identification of the automated clearing house of the New York Clearing House Association (CHIPS).
_44
Clearing House Interbank Payment System Universal ID
Universal identification of the automated clearing house of the New York Clearing House Association (CHIPS).
_45
United Nations Common Coding System (UNCCS)
A code list adopted by the United Nations organisations for the procurement of goods and services.
_46
DUNS (Dun and Bradstreet) +4
An organization identified by the DUNS number and a 4- character extension.
_47
Occupation classification
Identifies the class of occupation.
_48
Policy reserve valuation type
Identification of the policy reserve valuation type.
_49
Life reinsurance message type
To indicate the type of life reinsurance activity transmitted in the message.
_52
Value added tax identification
Value added tax identification code.
_53
Passport number
Number assigned to a passport.
_54
Statistical object
A statistical object such as a statistical concept, array structure component or statistical nomenclature.
_55
Quality conformance
A code list specifying the quality standard a product complies with, e.g. ISO9000, BS5750, etc.
_56
Safety regulation
A code list specifying the safety regulations which apply to a product, such as UK COSHH (control of substances hazardous to health) regulations.
_57
Product code
Code assigned to a specific product by a controlling agency.
_58
Business account number
An identifying number or code assigned by issuing authorities to manage business activities.
_59
Railway services harmonized code
Services provided by the different railway organizations.
_60
Type of financial account
Identification of the type of financial account.
_61
Type of assets and liabilities
Identification of the type of assets and liabilities.
_62
Requirements indicator
A code list which specifies various requirements that a customer may have when fulfilling a purchase order.
_63
Handling action
Codes for handling action.
_64
Freight forwarder
Codes for freight forwarders.
_65
Shipping agent
Codes for shipping agents.
_67
Type of package
Indication of the type of package codes.
_68
Type of industrial activity
Identification of the type of industrial activity.
_69
Type of survey question
Identification of the type of survey question.
_70
Customs inspection type
A code to indicate the type of inspection performed by customs.
_71
Nature of transaction
Identification of the nature of the transaction.
_72
Container terminal
Codes for container terminal.
_73
Insurance information indicator
Identifies the type of insurance information provided.
_74
Joint life insurance indicator
Indicates joint life insurance coverage.
_75
Bill of lading clauses
Code list identifying official clauses associated with bills of lading.
_76
Export commodity classification (US Schedule B)
Code list containing the commodity classifications applying to goods being exported (United States Schedule B).
_77
Customs domestic port location codes (US Schedule D)
Code list containing Customs domestic port locations (United States Schedule D).
_78
Customs foreign port location codes (US Schedule K)
Code list containing Customs foreign port locations (United States Schedule K).
_79
Functional group
Identifies a group of application related messages.
_80
Application error code
A code list specifying application errors.
_81
Policy type
To identify the code list for the type of policy.
_82
Type of insured
To specify the insured type.
_83
Occupation code
Identification of an occupation.
_84
State code
A code list of states within a country.
_85
Technical Assessment Checklist (TAC)
A code list of technical assessment checklist numbers.
_86
Syntax notes
A code list of syntax (dependency) note identifiers.
_100
Enhanced party identification
_101
Air carrier
_102
Size and type
_103
Call sign directory
A directory of call signs assigned to transport vehicles.
_104
Customs area of transaction
Customs code to indicate the different types of declarations according to the countries involved in the transaction (e.g. box 1/1 of SAD: inter EC Member States, EC-EFTA, EC-third countries, etc.).
_105
Customs declaration type
Customs code to indicate the type of declaration according to the different Customs procedures requested (e.g.: import, export, transit).
_106
Incoterms 1980
(4110) Code to indicate applicable Incoterm (1980 edition) under which seller undertakes to deliver merchandise to buyer (ICC). Incoterms 1990: use 4053 only.
_107
Excise duty
Customs or fiscal authorities code to identify a specific or ad valorem levy on a specific commodity, applied either domestically or at time of importation.
_108
Tariff schedule
_109
Customs indicator
Customs code for circumstances where only an indication is needed.
_110
Customs special codes
Customs code to indicate an exemption to a regulation or a special Customs treatment.
_112
Statistical nature of transaction
Indication of the type of contract under which goods are supplied.
_113
Customs office
Customs administrative unit competent for the performance of Customs formalities, and the premises or other areas approved for the purpose by the competent authorities (CCC).
_114
Railcar letter marking
Codes for all marking codes (in letters) for railcars specifying the type, series, order number, check digit and some technical characteristics.
_115
Examination facility
Building or location where merchandise is examined by Customs.
_116
Customs preference
Customs code to identify a specific tariff preference.
_117
Customs procedure
(9380) Customs code to identify goods which are subject to Customs control (e.g. home use, Customs warehousing, temporary admission, Customs transit).
_118
Government agency procedure
Treatment applied by a government agency other than Customs to merchandise under their control.
_119
Customs simplified procedure
Customs code to indicate the type of simplified Customs procedure requested by a declarant (CCC).
_120
Customs status of goods
Customs code to specify the status accorded by Customs to a consignment e.g. release without further formality, present supporting documents for inspection, etc (CCC).
_121
Shipment description
Code to indicate whether a shipment is a total, part or split consignment.
_122
Commodity
(7357) Code identifying types of goods for Customs, transport or statistical purposes (generic term).
_123
Entitlement
Code to indicate the recipient of a charge amount (IATA).
_125
Customs transit guarantee
Customs code to identify the type of guarantee used in a transit movement.
_126
Accounting information identifier
Identification of a specific kind of accounting information.
_127
Customs valuation method
Customs code to identify the valuation method used to determine the dutiable value of the declared goods.
_128
Service
Identification of services.
_129
Customs warehouse
Identification and/or location of the Customs warehouse in which goods will be or have been deposited (CCC).
_130
Special handling
Code to indicate that the nature of the consignment may necessitate use of special handling procedures (IATA).
_131
Free zone
Code identifying the zone within a state where any goods introduced are generally regarded, insofar as import duties and taxes are concerned, as being outside the Customs territory and are not subject to the usual Customs control.
_132
Charge
Identification of a type of charge.
_133
Financial regime
Nature and methods of a transaction from financial viewpoint.
_134
Duty, tax or fee payment method
[4390] Method by which a duty or tax is paid to the relevant administration.
_135
Rate class
Code to identify a specific rate category.
_136
Restrictions and prohibitions placed on the re-use of designated rail wagons
A code list identifying restrictions and prohibitions placed on the re-use of designated rail wagons.
_137
Rail harmonized codification of tariffs
A list of rail tariffs, the coding of which has been harmonized.
_139
Port
A location having facilities for means of transport to load or discharge cargo.
_140
Area
Codes for specific geographic areas e.g. seas, straits, basins etc.
_141
Forwarding restrictions
A code list containing restrictions regarding the forwarding of goods or equipment.
_142
Train identification
A code list specifying international train identifications maintained by the UIC (International Union of Railways).
_143
Removable accessories and special equipment on railcars
A list of removable accessories and special equipment associated with railcars.
_144
Rail routes
A code list identifying routes used in rail transport.
_145
Airport/city
As described and published by IATA.
_146
Means of transport identification
Code identifying the name or number of a means of transport (vessel, vehicle).
_147
Document requested by Customs
Customs code to identify documents requested by Customs in an information interchange.
_148
Customs release notification
Authorisation given by Customs to move the goods or not move the goods from the place of registration.
_149
Customs transit type
Customs code to indicate the different kinds of transit movement of the goods (e.g. Box 1/3 of the SAD).
_150
Financial routing
_151
Locations for tariff calculations
A list of locations related to tariff calculations.
_152
Materials
_153
Methods of payment
Identification of methods of payment.
_154
Bank branch sorting identification
Identification of a specific branch of a bank.
_155
Automated clearing house
Identification of automated clearing houses.
_156
Location of goods
(3384) Indication of the place where goods are located and where they are available for examination.
_157
Clearing code
Identification of the responsible bank/clearing house which has cleared or is ordered to do the clearing.
_158
Terms of delivery
Code to identify terms of delivery.
_160
Party identification
Identification of parties, corporates, etc.
_161
Goods description
Identification of a type of goods description.
_162
Country
Identification of a country.
_163
Country sub-entity
(3228) Identification of country sub-entity (region, department, state, province) defined by appropriate authority.
_164
Member organizations
Identification of member organizations.
_165
Amendment code (Customs)
Customs code indicating the reason for transmitting an amendment to Customs.
_166
Social security identification
Code assigned by the authority competent to issue social security identification to identify a person.
_167
Tax party identification
Code assigned by a tax authority to identify a party.
_168
Rail document names
Rail specific identifications of documents.
_169
Harmonized system
Identification of commodities according to the Harmonized System.
_170
Bank securities code
_172
Carriers
Code list identifying carriers.
_173
Export requirements
Identification of requirements and regulations established by relevant authorities concerning exportation.
_174
Citizen identification
_175
Account analysis codes
Account service charges list.
_176
Flow of the goods
List of statistical codes covering the movement of the goods to be declared (e.g. despatch, arrival).
_177
Statistical procedures
Indication of the statistical procedure to which the goods are subject.
_178
Standard text according US embargo regulations
US government regulations prescribe specific standard text usage. Using codes from this code list prevents full text transmission.
_179
Standard text for export according national prescriptions
National export regulations prescribe specific standard text usage. Using codes from this code list prevents full text transmission.
_180
Airport terminal
Code identifying terminals or other sub-locations at airports.
_181
Activity
Code identifying activities.
_182
Combiterms 1990
Code to indicate the applicable Combiterm (1990 edition), used for the purpose of cost distribution between seller according to Incoterms 1990.
_183
Dangerous goods packing type
Identification of package types for the description related to dangerous goods.
_184
Tax assessment method
A code to identify the tax assessment method.
_185
Item type
A code list defining the level of elaboration of a item such as raw material, component, tooling, etc.
_186
Product supply condition
A code list specifying the rules according to which a product is supplied, e.g. from stock, available on demand, make on order, etc.
_187
Supplier’s stock turnover
A code list giving an indication about the level of the supplier’s stock turnover.
_188
Article status
A code list defining the status of an article from the procurement point of view, e.g. new article, critical article, etc.
_189
Quality control code
A code list specifying how the article is classified according to the quality control point of view, e.g. safety item, subject to regulation, etc.
_190
Item sourcing category
A code list to specify details related to the sourcing of the corresponding item such as provided by the buyer, from a mandatory source, etc.
_191
Dumping or countervailing assessment method
A code to identify the method used to determine the dumping or countervailing duty.
_192
Dumping specification
Code list to identify types of goods for dumping purposes.
_193
Legal event
Identifies a code list of legal events.
_194
Record precedence based on its currency in time
Identifies the priority of a record based on its currency in time.
_195
Ownership rights
Identifies a code list containing types of ownership rights.
_196
Property ownership extent
Identifies a code list containing the extent of legal rights of possession to property.
_197
Monetary function detail
Identifies a code list containing monetary function details.
_198
Account relationship type
Identifies a code list containing types of account relationships.
_199
Account rating
Identifies the code list containing account rating types.
_200
Loan type
Identifies the code list of loan types.
_201
Claim type
Identifies the code list containing the claim types.
_202
Legal case type
Identifies the code list containing the type of legal cases.
_203
Court of law event type
Identifies the code list containing the type of law events.
_204
Notice type
Identifies the code list containing the type of notice.
_205
Ethnicity
Identifies the code list containing ethnic types.
_206
Individual participation in company
Identifies the code list containing the types of participation of an individual within a company.
_207
Real estate asset type
Identifies the code list containing the types of real estate assets.
_208
Asset recurrence
Identifies the code list containing the types of recurrences of assets.
_209
Construction material
Identifies the code list containing types of materials used for construction.
_210
Information request type
Identifies a code list containing types of information requests.
_211
Business change
Identifies a code list containing business change types.
_212
Business credit rating
Identifies a code list containing business credit rating types.
_213
Corporate financial filing criteria
Identifies a code list containing criteria for corporate financial filings.
_214
Reason for public record filing
Identifies a code list containing reasons for public record filings.
_215
Registration type
Identifies a code list containing registration types.
_216
Stock exchange detail
Identifies a code list containing stock exchange details.
_217
Business legal structure type
Identifies a code list containing business legal structure details.
_218
Information request result
Identifies a code list containing information request results.
_219
Financial information type
Identifies a code list containing financial information types.
_220
Consolidation detail
Identifies a code list containing consolidation details.
_221
Condition detail
Identifies a code list containing condition details.
_222
Financial statement format
Identifies a code list containing financial statement formats.
_223
Source of disclosure
Identifies a code list containing disclosure sources.
_224
General territory type
Identifies a code list containing general territory types.
_225
Roadway type
Identifies a code list containing roadway types.
_226
Roadway detail
Identifies a code list containing roadway details.
_227
City
Identifies a code list containing cities.
_228
County
Identifies a code list containing counties. A county is any of the territorial divisions of some countries, forming the chief unit of local administration.
_229
Geographic location
Identifies a code list containing geographic locations.
_230
Entity relationship
Identifies a code list of entity relationships.
_231
Payment behaviour rating
Identifies a code list containing payment behaviour ratings.
_232
Inquiry selection
Identifies a code list containing inquiry selections.
_233
Rating summary value
Identifies a code list containing rating summary values.
_234
Industry rating
Identifies a code list containing industry ratings.
_235
Forecast type
Identifies a code list containing forecast types.
_236
Hobby
Identifies a code list containing hobby types.
_237
Functional business area
Identifies a code list containing functional business areas.
_238
Current asset details
Identifies a code list containing details of the current asset types.
_239
Asset details
Identifies a code list containing details of the asset types.
_240
Current liability details
Identifies a code list containing the current liability types.
_241
Liability details
Identifies a code list containing details of liability types.
_242
Financial item reclassification
Identifies a code list containing financial item reclassifications.
_243
Financial item allocation
Identifies a code list containing financial item allocations.
_244
Reason for financial item detail change
Identifies a code list containing reasons for the change in financial item details.
_245
Educational institution type
Identifies a code list containing educational institution types.
_246
Educational study area
Identifies a code list containing educational study areas.
_247
Security share type
Identifies a code list containing security share types.
_248
Insurance coverage detail
Identifies a code list containing insurance coverage details.
_249
Property type
Identifies a code list containing property types.
_250
Data category
Identifies a code list containing data categories.
_251
Information type
Identifies a code list containing types of information.
_252
Court of law type
Identifies a code list containing court of law types.
_253
Region
Identifies a code list containing regions that identify an area of the earth’s surface, having definable boundaries or characteristics.
_254
Postal service carrier route
Identifies a code list containing routes covered by a postal service carrier.
_255
Continent
Identifies a code list containing continents, that are any of the main continuous expanses of land.
_256
Postal district
Identifies a code list containing territories for the routing of mail.
_257
Non-postal town
Identifies a code list containing towns not recognised as a postal entity.
_258
City subdivision
Identifies a code list containing subdivisions of a city.
_259
Financial analysis categories
Identifies a code list containing financial analysis categories.
_260
Accord Europeen relatif au transport international des marchandises(ADR).
A code list identifying dangerous goods for transport purposes.
_261
Consignee’s premises
Facility controlled by the consignee of cargo.
_262
Consignor’s premises
Facility controlled by the consignor of cargo.
_263
Packing and/or unpacking facility
Facility dedicated to the packing and/or unpacking of cargo.
_264
Storage facility
Facility at which goods are stored.
_265
Repair facility
Facility at which repairs are carried out.
_266
Marine berth
The location within a port where a ship anchors or ties up.
_267
Marine wharf
Landing platform where a ship can load and unload.
_268
Gate
The location at which access to or from a facility is controlled.
_269
Warehouse
A covered facility for the storage and distribution of goods.
_270
Business classification
Code list of business classifications.
_271
Facility security clearance
Code list specifying the security clearance assigned to a facility.
_272
Individual security clearance
Code list specifying the security clearance assigned to an individual.
_273
Means of communications identifier
Code list of communication means used to transmit data.
_ZZZ
Mutually defined