pub enum _6063 {
Show 444 variants
_1,
_2,
_3,
_4,
_5,
_6,
_7,
_8,
_9,
_10,
_11,
_12,
_13,
_14,
_15,
_16,
_17,
_18,
_19,
_20,
_21,
_22,
_23,
_24,
_25,
_26,
_27,
_28,
_29,
_30,
_31,
_32,
_33,
_34,
_35,
_36,
_37,
_38,
_39,
_40,
_41,
_42,
_43,
_44,
_45,
_46,
_47,
_48,
_49,
_50,
_51,
_52,
_53,
_54,
_55,
_56,
_57,
_58,
_59,
_60,
_61,
_62,
_63,
_64,
_65,
_66,
_67,
_68,
_69,
_70,
_71,
_72,
_73,
_74,
_75,
_76,
_77,
_78,
_79,
_80,
_81,
_82,
_83,
_84,
_85,
_86,
_87,
_88,
_89,
_90,
_91,
_92,
_93,
_94,
_95,
_96,
_97,
_98,
_99,
_100,
_101,
_102,
_103,
_104,
_105,
_106,
_107,
_108,
_109,
_110,
_111,
_112,
_113,
_114,
_115,
_116,
_117,
_118,
_119,
_120,
_121,
_122,
_123,
_124,
_125,
_126,
_127,
_128,
_129,
_130,
_131,
_132,
_133,
_134,
_135,
_136,
_137,
_138,
_139,
_140,
_141,
_142,
_143,
_144,
_145,
_146,
_147,
_148,
_149,
_150,
_151,
_152,
_153,
_154,
_155,
_156,
_157,
_158,
_159,
_160,
_161,
_162,
_163,
_164,
_165,
_166,
_167,
_168,
_169,
_170,
_171,
_172,
_173,
_174,
_175,
_176,
_177,
_178,
_179,
_180,
_181,
_182,
_183,
_184,
_185,
_186,
_187,
_188,
_189,
_190,
_191,
_192,
_193,
_194,
_195,
_196,
_197,
_198,
_199,
_200,
_201,
_202,
_203,
_204,
_205,
_206,
_207,
_208,
_209,
_210,
_211,
_212,
_213,
_214,
_215,
_216,
_217,
_218,
_219,
_220,
_221,
_222,
_223,
_224,
_225,
_226,
_227,
_228,
_229,
_230,
_231,
_232,
_233,
_234,
_235,
_236,
_237,
_238,
_239,
_240,
_241,
_242,
_243,
_244,
_245,
_246,
_247,
_248,
_249,
_250,
_251,
_252,
_253,
_254,
_255,
_256,
_257,
_258,
_259,
_260,
_261,
_262,
_263,
_264,
_265,
_266,
_267,
_268,
_269,
_270,
_271,
_272,
_273,
_274,
_275,
_276,
_277,
_278,
_279,
_280,
_281,
_282,
_283,
_284,
_285,
_286,
_287,
_288,
_289,
_290,
_291,
_292,
_293,
_294,
_295,
_296,
_297,
_298,
_299,
_300,
_301,
_302,
_303,
_304,
_305,
_306,
_307,
_308,
_309,
_310,
_311,
_312,
_313,
_314,
_315,
_316,
_317,
_318,
_319,
_320,
_321,
_322,
_323,
_324,
_325,
_326,
_327,
_328,
_329,
_330,
_331,
_332,
_333,
_334,
_335,
_336,
_337,
_338,
_339,
_340,
_341,
_342,
_343,
_344,
_345,
_346,
_347,
_348,
_349,
_350,
_351,
_352,
_353,
_354,
_355,
_356,
_357,
_358,
_359,
_360,
_361,
_362,
_363,
_364,
_365,
_366,
_367,
_368,
_369,
_370,
_371,
_372,
_373,
_374,
_375,
_376,
_377,
_378,
_379,
_380,
_381,
_382,
_383,
_384,
_385,
_386,
_387,
_388,
_389,
_390,
_391,
_392,
_393,
_394,
_395,
_396,
_397,
_398,
_399,
_400,
_401,
_402,
_403,
_404,
_405,
_406,
_407,
_408,
_409,
_410,
_411,
_412,
_413,
_414,
_415,
_416,
_417,
_418,
_419,
_420,
_421,
_422,
_423,
_424,
_425,
_426,
_427,
_428,
_429,
_430,
_431,
_432,
_433,
_434,
_435,
_436,
_437,
_438,
_439,
_440,
_441,
_442,
_443,
ZZZ,
}Expand description
Quantity type code qualifier
Code qualifying the type of quantity.
Variants
_1
Discrete quantity
_2
Charge
Quantity relevant for charge.
_3
Cumulative quantity
_4
Interest for overdrawn account
Interest for overdrawing the account.
_5
Active ingredient dose per unit
The dosage of active ingredient per unit.
_6
Auditor
The number of entities that audit accounts.
_7
Branch locations, leased
The number of branch locations being leased by an entity.
_8
Inventory quantity at supplier’s subject to inspection by customer
Quantity of goods which the customer requires the supplier to have in inventory and which may be inspected by the customer if desired.
_9
Branch locations, owned
The number of branch locations owned by an entity.
_10
Judgements registered
The number of judgements registered against an entity.
_11
Split quantity
Part of the whole quantity.
_12
Despatch quantity
Quantity despatched by the seller.
_13
Liens registered
The number of liens registered against an entity.
_14
Livestock
The number of animals kept for use or profit.
_15
Insufficient funds returned cheques
The number of cheques returned due to insufficient funds.
_16
Stolen cheques
The number of stolen cheques.
_17
Quantity on hand
The total quantity of a product on hand at a location. This includes as well units awaiting return to manufacturer, units unavailable due to inspection procedures and undamaged stock available for despatch, resale or use.
_18
Previous quantity
Quantity previously referenced.
_19
Paid-in security shares
The number of security shares issued and for which full payment has been made.
_20
Unusable quantity
_21
Ordered quantity
The quantity which has been ordered.
_22
Quantity at 100%
Equivalent quantity at 100% purity.
_23
Active ingredient
Quantity at 100% active agent content.
_24
Inventory quantity at supplier’s not subject to inspection by customer
Quantity of goods which the customer requires the supplier to have in inventory but which will not be checked by the customer.
_25
Retail sales
Quantity of retail point of sale activity.
_26
Promotion quantity
A quantity associated with a promotional event.
_27
On hold for shipment
Article received which cannot be shipped in its present form.
_28
Military sales quantity
Quantity of goods or services sold to a military organization.
_29
On premises sales
Sale of product in restaurants or bars.
_30
Off premises sales
Sale of product directly to a store.
_31
Estimated annual volume
_32
Minimum delivery batch
_33
Maximum delivery batch
_34
Pipes
The number of tubes used to convey a substance.
_35
Price break from
The minimum quantity of a quantity range for a specified (unit) price.
_36
Price break to
Description to be provided.
_37
Poultry
The number of domestic fowl.
_38
Secured charges registered
The number of secured charges registered against an entity.
_39
Total properties owned
The total number of properties owned by an entity.
_40
Normal delivery
Quantity normally delivered by the seller.
_41
Sales quantity not included in the replenishment calculation
Sales which will not be included in the calculation of replenishment requirements.
_42
Maximum supply quantity, supplier endorsed
Maximum supply quantity endorsed by a supplier.
_43
Buyer
The number of buyers.
_44
Debenture bond
The number of fixed-interest bonds of an entity backed by general credit rather than specified assets.
_45
Debentures filed against directors
The number of notices of indebtedness filed against an entity’s directors.
_46
Pieces delivered
Number of pieces actually received at the final destination.
_47
Invoiced quantity
The quantity as per invoice.
_48
Received quantity
The quantity which has been received.
_49
Chargeable distance
Distance really charged by tariff appliance.
_50
Disposition undetermined quantity
Product quantity that has not yet had its disposition determined.
_51
Inventory category transfer
Inventory that has been moved from one inventory category to another.
_52
Quantity per pack
_53
Minimum order quantity
_54
Maximum order quantity
_55
Total sales
The summation of total quantity sales.
_56
Wholesaler to wholesaler sales
Sale of product to other wholesalers by a wholesaler.
_57
In transit quantity
A quantity that is en route.
_58
Quantity withdrawn
Quantity withdrawn from a location.
_59
Numbers of consumer units in the traded unit
_60
Current inventory quantity available for shipment
Current inventory quantity available for shipment.
_61
Return quantity
_62
Sorted quantity
Description to be provided.
_63
Sorted quantity rejected
Description to be provided.
_64
Scrap quantity
Remainder of the total quantity after split deliveries.
_65
Destroyed quantity
_66
Committed quantity
Quantity a party is committed to.
_67
Estimated reading quantity
The value that is estimated to be the reading of a measuring device (e.g. meter).
_68
End quantity
The quantity recorded at the end of an agreement or period.
_69
Start quantity
The quantity recorded at the start of an agreement or period.
_70
Cumulative quantity received
Cumulative quantity of all deliveries of this article received by the buyer.
_71
Cumulative quantity ordered
Cumulative quantity of all deliveries, outstanding and scheduled orders.
_72
Cumulative quantity received end of prior year
Cumulative quantity of all deliveries of the product received by the buyer till end of prior year.
_73
Outstanding quantity
Difference between quantity ordered and quantity received.
_74
Latest cumulative quantity
Cumulative quantity after complete delivery of all scheduled quantities of the product.
_75
Previous highest cumulative quantity
Cumulative quantity after complete delivery of all scheduled quantities of the product from a prior schedule period.
_76
Adjusted corrector reading
A corrector reading after it has been adjusted.
_77
Work days
Number of work days, e.g. per respective period.
_78
Cumulative quantity scheduled
Adding the quantity actually scheduled to previous cumulative quantity.
_79
Previous cumulative quantity
Cumulative quantity prior the actual order.
_80
Unadjusted corrector reading
A corrector reading before it has been adjusted.
_81
Extra unplanned delivery
Non scheduled additional quantity.
_82
Quantity requirement for sample inspection
_83
Backorder quantity
_84
Urgent delivery quantity
_85
Previous order quantity to be cancelled
_86
Normal reading quantity
The value recorded or read from a measuring device (e.g. meter) in the normal conditions.
_87
Customer reading quantity
The value recorded or read from a measuring device (e.g. meter) by the customer.
_88
Information reading quantity
The value recorded or read from a measuring device (e.g. meter) for information purposes.
_89
Quality control held
Quantity of goods held pending completion of a quality control assessment.
_90
As is quantity
_91
Open quantity
Quantity remaining after partial delivery.
_92
Final delivery quantity
Quantity of final delivery to a respective order.
_93
Subsequent delivery quantity
Quantity delivered to a respective order after it’s final delivery.
_94
Substitutional quantity
Quantity delivered replacing previous deliveries.
_95
Redelivery after post processing
_96
Quality control failed
Quantity of goods which have failed quality control.
_97
Minimum inventory
Minimum stock quantity on which replenishment is based.
_98
Maximum inventory
Maximum stock quantity on which replenishment is based.
_99
Estimated quantity
_100
Chargeable weight
The weight on which charges are based.
_101
Chargeable gross weight
The gross weight on which charges are based.
_102
Chargeable tare weight
The tare weight on which charges are based.
_103
Chargeable number of axles
The number of axles on which charges are based.
_104
Chargeable number of containers
The number of containers on which charges are based.
_105
Chargeable number of rail wagons
The number of rail wagons on which charges are based.
_106
Chargeable number of packages
The number of packages on which charges are based.
_107
Chargeable number of units
The number of units on which charges are based.
_108
Chargeable period
The period of time on which charges are based.
_109
Chargeable volume
The volume on which charges are based.
_110
Chargeable cubic measurements
The cubic measurements on which charges are based.
_111
Chargeable surface
The surface area on which charges are based.
_112
Chargeable length
The length on which charges are based.
_113
Quantity to be delivered
The quantity to be delivered.
_114
Number of passengers
Total number of passengers on the conveyance.
_115
Number of crew
Total number of crew members on the conveyance.
_116
Number of transport documents
Total number of air waybills, bills of lading, etc. being reported for a specific conveyance.
_117
Quantity landed
Quantity of goods actually arrived.
_118
Quantity manifested
Quantity of goods contracted for delivery by the carrier.
_119
Short shipped
Indication that part of the consignment was not shipped.
_120
Split shipment
Indication that the consignment has been split into two or more shipments.
_121
Over shipped
Indication that more goods have been shipped than contracted for delivery.
_122
Short-landed goods
If quantity of goods actually landed is less than the quantity which appears in the documentation. This quantity is the difference between these quantities.
_123
Surplus goods
If quantity of goods actually landed is more than the quantity which appears in the documentation. This quantity is the difference between these quantities.
_124
Damaged goods
Quantity of goods which have deteriorated in transport such that they cannot be used for the purpose for which they were originally intended.
_125
Pilferage goods
Quantity of goods stolen during transport.
_126
Lost goods
Quantity of goods that disappeared in transport.
_127
Report difference
The quantity concerning the same transaction differs between two documents/messages and the source of this difference is a typing error.
_128
Quantity loaded
Quantity of goods loaded onto a means of transport.
_129
Units per unit price
Number of units per unit price.
_130
Allowance
Quantity relevant for allowance.
_131
Delivery quantity
Quantity required by buyer to be delivered.
_132
Cumulative quantity, preceding period, planned
Cumulative quantity originally planned for the preceding period.
_133
Cumulative quantity, preceding period, reached
Cumulative quantity reached in the preceding period.
_134
Cumulative quantity, actual planned
Cumulative quantity planned for now.
_135
Period quantity, planned
Quantity planned for this period.
_136
Period quantity, reached
Quantity reached during this period.
_137
Cumulative quantity, preceding period, estimated
Estimated cumulative quantity reached in the preceding period.
_138
Cumulative quantity, actual estimated
Estimated cumulative quantity reached now.
_139
Cumulative quantity, preceding period, measured
Surveyed cumulative quantity reached in the preceding period.
_140
Cumulative quantity, actual measured
Surveyed cumulative quantity reached now.
_141
Period quantity, measured
Surveyed quantity reached during this period.
_142
Total quantity, planned
Total quantity planned.
_143
Quantity, remaining
Quantity remaining.
_144
Tolerance
Plus or minus tolerance expressed as a monetary amount.
_145
Actual stock
The stock on hand, undamaged, and available for despatch, sale or use.
_146
Model or target stock
The stock quantity required or planned to have on hand, undamaged and available for use.
_147
Direct shipment quantity
Quantity to be shipped directly to a customer from a manufacturing site.
_148
Amortization total quantity
Indication of final quantity for amortization.
_149
Amortization order quantity
Indication of actual share of the order quantity for amortization.
_150
Amortization cumulated quantity
Indication of actual cumulated quantity of previous and actual amortization order quantity.
_151
Quantity advised
Quantity advised by supplier or shipper, in contrast to quantity actually received.
_152
Quantity on hand
The total quantity of a product on hand at a location. This includes as well units awaiting return to manufacturer, units unavailable due to inspection procedures and undamaged stock available for despatch, resale or use.
_153
Statistical sales quantity
Quantity of goods sold in a specified period.
_154
Sales quantity planned
Quantity of goods required to meet future demands. - Market intelligence quantity.
_155
Replenishment quantity
Quantity required to maintain the requisite on-hand stock of goods.
_156
Inventory movement quantity
To specify the quantity of an inventory movement.
_157
Opening stock balance quantity
To specify the quantity of an opening stock balance.
_158
Closing stock balance quantity
To specify the quantity of a closing stock balance.
_159
Number of stops
Number of times a means of transport stops before arriving at destination.
_160
Minimum production batch
The quantity specified is the minimum output from a single production run.
_161
Dimensional sample quantity
The quantity defined is a sample for the purpose of validating dimensions.
_162
Functional sample quantity
The quantity defined is a sample for the purpose of validating function and performance.
_163
Pre-production quantity
Quantity of the referenced item required prior to full production.
_164
Delivery batch
Quantity of the referenced item which constitutes a standard batch for deliver purposes.
_165
Delivery batch multiple
The multiples in which delivery batches can be supplied.
_166
All time buy
The total quantity of the referenced covering all future needs. Further orders of the referenced item are not expected.
_167
Total delivery quantity
The total quantity required by the buyer to be delivered.
_168
Single delivery quantity
The quantity required by the buyer to be delivered in a single shipment.
_169
Supplied quantity
Quantity of the referenced item actually shipped.
_170
Allocated quantity
Quantity of the referenced item allocated from available stock for delivery.
_171
Maximum stackability
The number of pallets/handling units which can be safely stacked one on top of another.
_172
Amortisation quantity
The quantity of the referenced item which has a cost for tooling amortisation included in the item price.
_173
Previously amortised quantity
The cumulative quantity of the referenced item which had a cost for tooling amortisation included in the item price.
_174
Total amortisation quantity
The total quantity of the referenced item which has a cost for tooling amortisation included in the item price.
_175
Number of moulds
The number of pressing moulds contained within a single piece of the referenced tooling.
_176
Concurrent item output of tooling
The number of related items which can be produced simultaneously with a single piece of the referenced tooling.
_177
Periodic capacity of tooling
Maximum production output of the referenced tool over a period of time.
_178
Lifetime capacity of tooling
Maximum production output of the referenced tool over its productive lifetime.
_179
Number of deliveries per despatch period
The number of deliveries normally expected to be despatched within each despatch period.
_180
Provided quantity
The quantity of a referenced component supplied by the buyer for manufacturing of an ordered item.
_181
Maximum production batch
The quantity specified is the maximum output from a single production run.
_182
Cancelled quantity
Quantity of the referenced item which has previously been ordered and is now cancelled.
_183
No delivery requirement in this instruction
This delivery instruction does not contain any delivery requirements.
_184
Quantity of material in ordered time
Quantity of the referenced material within the ordered time.
_185
Rejected quantity
The quantity of received goods rejected for quantity reasons.
_186
Cumulative quantity scheduled up to accumulation start date
The cumulative quantity scheduled up to the accumulation start date.
_187
Quantity scheduled
The quantity scheduled for delivery.
_188
Number of identical handling units
Number of identical handling units in terms of type and contents.
_189
Number of packages in handling unit
The number of packages contained in one handling unit.
_190
Despatch note quantity
The item quantity specified on the despatch note.
_191
Adjustment to inventory quantity
An adjustment to inventory quantity.
_192
Free goods quantity
Quantity of goods which are free of charge.
_193
Free quantity included
Quantity included to which no charge is applicable.
_194
Received and accepted
Quantity which has been received and accepted at a given location.
_195
Received, not accepted, to be returned
Quantity which has been received but not accepted at a given location and which will consequently be returned to the relevant party.
_196
Received, not accepted, to be destroyed
Quantity which has been received but not accepted at a given location and which will consequently be destroyed.
_197
Reordering level
Quantity at which an order may be triggered to replenish.
_198
Quantity in transit
Quantity which is currently in transit.
_199
Inventory withdrawal quantity
Quantity which has been withdrawn from inventory since the last inventory report.
_200
Free quantity not included
Free quantity not included in ordered quantity.
_201
Recommended overhaul and repair quantity
To indicate the recommended quantity of an article required to support overhaul and repair activities.
_202
Quantity per next higher assembly
To indicate the quantity required for the next higher assembly.
_203
Quantity per unit of issue
Provides the standard quantity of an article in which one unit can be issued.
_204
Cumulative scrap quantity
Provides the cumulative quantity of an item which has been identified as scrapped.
_205
Publication turn size
The quantity of magazines or newspapers grouped together with the spine facing alternate directions in a bundle.
_206
Recommended maintenance quantity
Recommended quantity of an article which is required to meet an agreed level of maintenance.
_207
Labour hours
Number of labour hours.
_208
Quantity requirement for maintenance and repair of equipment
Quantity of the material needed to maintain and repair equipment.
_209
Additional replenishment demand quantity
Incremental needs over and above normal replenishment calculations, but not intended to permanently change the model parameters.
_210
Returned by consumer quantity
Quantity returned by a consumer.
_211
Replenishment override quantity
Quantity to override the normal replenishment model calculations, but not intended to permanently change the model parameters.
_212
Quantity sold, net
Net quantity sold which includes returns of saleable inventory and other adjustments.
_213
Transferred out quantity
Quantity which was transferred out of this location.
_214
Transferred in quantity
Quantity which was transferred into this location.
_215
Unsaleable quantity
Quantity of inventory received which cannot be sold in its present condition.
_216
Consumer reserved quantity
Quantity reserved for consumer delivery or pickup and not yet withdrawn from inventory.
_217
Out of inventory quantity
Quantity of inventory which was requested but was not available.
_218
Quantity returned, defective or damaged
Quantity returned in a damaged or defective condition.
_219
Taxable quantity
Quantity subject to taxation.
_220
Meter reading
The numeric value of measure units counted by a meter.
_221
Maximum requestable quantity
The maximum quantity which may be requested.
_222
Minimum requestable quantity
The minimum quantity which may be requested.
_223
Daily average quantity
The quantity for a defined period divided by the number of days of the period.
_224
Budgeted hours
The number of budgeted hours.
_225
Actual hours
The number of actual hours.
_226
Earned value hours
The number of earned value hours.
_227
Estimated hours
The number of estimated hours.
_228
Level resource task quantity
Quantity of a resource that is level for the duration of the task.
_229
Available resource task quantity
Quantity of a resource available to complete a task.
_230
Work time units
Quantity of work units of time.
_231
Daily work shifts
Quantity of work shifts per day.
_232
Work time units per shift
Work units of time per work shift.
_233
Work calendar units
Work calendar units of time.
_234
Elapsed duration
Quantity representing the elapsed duration.
_235
Remaining duration
Quantity representing the remaining duration.
_236
Original duration
Quantity representing the original duration.
_237
Current duration
Quantity representing the current duration.
_238
Total float time
Quantity representing the total float time.
_239
Free float time
Quantity representing the free float time.
_240
Lag time
Quantity representing lag time.
_241
Lead time
Quantity representing lead time.
_242
Number of months
The number of months.
_243
Reserved quantity customer direct delivery sales
Quantity of products reserved for sales delivered direct to the customer.
_244
Reserved quantity retail sales
Quantity of products reserved for retail sales.
_245
Consolidated discount inventory
A quantity of inventory supplied at consolidated discount terms.
_246
Returns replacement quantity
A quantity of goods issued as a replacement for a returned quantity.
_247
Additional promotion sales forecast quantity
A forecast of additional quantity which will be sold during a period of promotional activity.
_248
Reserved quantity
Quantity reserved for specific purposes.
_249
Quantity displayed not available for sale
Quantity displayed within a retail outlet but not available for sale.
_250
Inventory discrepancy
The difference recorded between theoretical and physical inventory.
_251
Incremental order quantity
The incremental quantity by which ordering is carried out.
_252
Quantity requiring manipulation before despatch
A quantity of goods which needs manipulation before despatch.
_253
Quantity in quarantine
A quantity of goods which are held in a restricted area for quarantine purposes.
_254
Quantity withheld by owner of goods
A quantity of goods which has been withheld by the owner of the goods.
_255
Quantity not available for despatch
A quantity of goods not available for despatch.
_256
Quantity awaiting delivery
Quantity of goods which are awaiting delivery.
_257
Quantity in physical inventory
A quantity of goods held in physical inventory.
_258
Quantity held by logistic service provider
Quantity of goods under the control of a logistic service provider.
_259
Optimal quantity
The optimal quantity for a given purpose.
_260
Delivery quantity balance
The difference between the scheduled quantity and the quantity delivered to the consignee at a given date.
_261
Cumulative quantity shipped
Cumulative quantity of all shipments.
_262
Quantity suspended
The quantity of something which is suspended.
_263
Control quantity
The quantity designated for control purposes.
_264
Equipment quantity
A count of a quantity of equipment.
_265
Factor
Number by which the measured unit has to be multiplied to calculate the units used.
_266
Unsold quantity held by wholesaler
Unsold quantity held by the wholesaler.
_267
Quantity held by delivery vehicle
Quantity of goods held by the delivery vehicle.
_268
Quantity held by retail outlet
Quantity held by the retail outlet.
_269
Rejected return quantity
A quantity for return which has been rejected.
_270
Accounts
The number of accounts.
_271
Accounts placed for collection
The number of accounts placed for collection.
_272
Activity codes
The number of activity codes.
_273
Agents
The number of agents.
_274
Airline attendants
The number of airline attendants.
_275
Authorised shares
The number of shares authorised for issue.
_276
Employee average
The average number of employees.
_277
Branch locations
The number of branch locations.
_278
Capital changes
The number of capital changes made.
_279
Clerks
The number of clerks.
_280
Companies in same activity
The number of companies doing business in the same activity category.
_281
Companies included in consolidated financial statement
The number of companies included in a consolidated financial statement.
_282
Cooperative shares
The number of cooperative shares.
_283
Creditors
The number of creditors.
_284
Departments
The number of departments.
_285
Design employees
The number of employees involved in the design process.
_286
Physicians
The number of medical doctors.
_287
Domestic affiliated companies
The number of affiliated companies located within the country.
_288
Drivers
The number of drivers.
_289
Employed at location
The number of employees at the specified location.
_290
Employed by this company
The number of employees at the specified company.
_291
Total employees
The total number of employees.
_292
Employees shared
The number of employees shared among entities.
_293
Engineers
The number of engineers.
_294
Estimated accounts
The estimated number of accounts.
_295
Estimated employees at location
The estimated number of employees at the specified location.
_296
Estimated total employees
The total estimated number of employees.
_297
Executives
The number of executives.
_298
Agricultural workers
The number of agricultural workers.
_299
Financial institutions
The number of financial institutions.
_300
Floors occupied
The number of floors occupied.
_301
Foreign related entities
The number of related entities located outside the country.
_302
Group employees
The number of employees within the group.
_303
Indirect employees
The number of employees not associated with direct production.
_304
Installers
The number of employees involved with the installation process.
_305
Invoices
The number of invoices.
_306
Issued shares
The number of shares actually issued.
_307
Labourers
The number of labourers.
_308
Manufactured units
The number of units manufactured.
_309
Maximum number of employees
The maximum number of people employed.
_310
Maximum number of employees at location
The maximum number of people employed at a location.
_311
Members in group
The number of members within a group.
_312
Minimum number of employees at location
The minimum number of people employed at a location.
_313
Minimum number of employees
The minimum number of people employed.
_314
Non-union employees
The number of employees not belonging to a labour union.
_315
Floors
The number of floors in a building.
_316
Nurses
The number of nurses.
_317
Office workers
The number of workers in an office.
_318
Other employees
The number of employees otherwise categorised.
_319
Part time employees
The number of employees working on a part time basis.
_320
Accounts payable average overdue days
The average number of days accounts payable are overdue.
_321
Pilots
The number of pilots.
_322
Plant workers
The number of workers within a plant.
_323
Previous number of accounts
The number of accounts which preceded the current count.
_324
Previous number of branch locations
The number of branch locations which preceded the current count.
_325
Principals included as employees
The number of principals which are included in the count of employees.
_326
Protested bills
The number of bills which are protested.
_327
Registered brands distributed
The number of registered brands which are being distributed.
_328
Registered brands manufactured
The number of registered brands which are being manufactured.
_329
Related business entities
The number of related business entities.
_330
Relatives employed
The number of relatives which are counted as employees.
_331
Rooms
The number of rooms.
_332
Salespersons
The number of salespersons.
_333
Seats
The number of seats.
_334
Shareholders
The number of shareholders.
_335
Shares of common stock
The number of shares of common stock.
_336
Shares of preferred stock
The number of shares of preferred stock.
_337
Silent partners
The number of silent partners.
_338
Subcontractors
The number of subcontractors.
_339
Subsidiaries
The number of subsidiaries.
_340
Law suits
The number of law suits.
_341
Suppliers
The number of suppliers.
_342
Teachers
The number of teachers.
_343
Technicians
The number of technicians.
_344
Trainees
The number of trainees.
_345
Union employees
The number of employees who are members of a labour union.
_346
Number of units
The quantity of units.
_347
Warehouse employees
The number of employees who work in a warehouse setting.
_348
Shareholders holding remainder of shares
Number of shareholders owning the remainder of shares.
_349
Payment orders filed
Number of payment orders filed.
_350
Uncovered cheques
Number of uncovered cheques.
_351
Auctions
Number of auctions.
_352
Units produced
The number of units produced.
_353
Added employees
Number of employees that were added to the workforce.
_354
Number of added locations
Number of locations that were added.
_355
Total number of foreign subsidiaries not included in financial statement
The total number of foreign subsidiaries not included in the financial statement.
_356
Number of closed locations
Number of locations that were closed.
_357
Counter clerks
The number of clerks that work behind a flat-topped fitment.
_358
Payment experiences in the last 3 months
The number of payment experiences received for an entity over the last 3 months.
_359
Payment experiences in the last 12 months
The number of payment experiences received for an entity over the last 12 months.
_360
Total number of subsidiaries not included in the financial statement
The total number of subsidiaries not included in the financial statement.
_361
Paid-in common shares
The number of paid-in common shares.
_362
Total number of domestic subsidiaries not included in financial statement
The total number of domestic subsidiaries not included in the financial statement.
_363
Total number of foreign subsidiaries included in financial statement
The total number of foreign subsidiaries included in the financial statement.
_364
Total number of domestic subsidiaries included in financial statement
The total number of domestic subsidiaries included in the financial statement.
_365
Total transactions
The total number of transactions.
_366
Paid-in preferred shares
The number of paid-in preferred shares.
_367
Employees
Code specifying the quantity of persons working for a company, whose services are used for pay.
_368
Active ingredient dose per unit, dispensed
The dosage of active ingredient per dispensed unit.
_369
Budget
Budget quantity.
_370
Budget, cumulative to date
Budget quantity, cumulative to date.
_371
Actual units
The number of actual units.
_372
Actual units, cumulative to date
The number of cumulative to date actual units.
_373
Earned value
Earned value quantity.
_374
Earned value, cumulative to date
Earned value quantity accumulated to date.
_375
At completion quantity, estimated
The estimated quantity when a project is complete.
_376
To complete quantity, estimated
The estimated quantity required to complete a project.
_377
Adjusted units
The number of adjusted units.
_378
Number of limited partnership shares
Number of shares held in a limited partnership.
_379
National business failure incidences
Number of firms in a country that discontinued with a loss to creditors.
_380
Industry business failure incidences
Number of firms in a specific industry that discontinued with a loss to creditors.
_381
Business class failure incidences
Number of firms in a specific class that discontinued with a loss to creditors.
_382
Mechanics
Number of mechanics.
_383
Messengers
Number of messengers.
_384
Primary managers
Number of primary managers.
_385
Secretaries
Number of secretaries.
_386
Detrimental legal filings
Number of detrimental legal filings.
_387
Branch office locations, estimated
Estimated number of branch office locations.
_388
Previous number of employees
The number of employees for a previous period.
_389
Asset seizers
Number of entities that seize assets of another entity.
_390
Out-turned quantity
The quantity discharged.
_391
Material on-board quantity, prior to loading
The material in vessel tanks, void spaces, and pipelines prior to loading.
_392
Supplier estimated previous meter reading
Previous meter reading estimated by the supplier.
_393
Supplier estimated latest meter reading
Latest meter reading estimated by the supplier.
_394
Customer estimated previous meter reading
Previous meter reading estimated by the customer.
_395
Customer estimated latest meter reading
Latest meter reading estimated by the customer.
_396
Supplier previous meter reading
Previous meter reading done by the supplier.
_397
Supplier latest meter reading
Latest meter reading recorded by the supplier.
_398
Maximum number of purchase orders allowed
Maximum number of purchase orders that are allowed.
_399
File size before compression
The size of a file before compression.
_400
File size after compression
The size of a file after compression.
_401
Securities shares
Number of shares of securities.
_402
Patients
Number of patients.
_403
Completed projects
Number of completed projects.
_404
Promoters
Number of entities who finance or organize an event or a production.
_405
Administrators
Number of administrators.
_406
Supervisors
Number of supervisors.
_407
Professionals
Number of professionals.
_408
Debt collectors
Number of debt collectors.
_409
Inspectors
Number of individuals who perform inspections.
_410
Operators
Number of operators.
_411
Trainers
Number of trainers.
_412
Active accounts
Number of accounts in a current or active status.
_413
Trademarks used
Number of trademarks used.
_414
Machines
Number of machines.
_415
Fuel pumps
Number of fuel pumps.
_416
Tables available
Number of tables available for use.
_417
Directors
Number of directors.
_418
Freelance debt collectors
Number of debt collectors who work on a freelance basis.
_419
Freelance salespersons
Number of salespersons who work on a freelance basis.
_420
Travelling employees
Number of travelling employees.
_421
Foremen
Number of workers with limited supervisory responsibilities.
_422
Production workers
Number of employees engaged in production.
_423
Employees not including owners
Number of employees excluding business owners.
_424
Beds
Number of beds.
_425
Resting quantity
A quantity of product that is at rest before it can be used.
_426
Production requirements
Quantity needed to meet production requirements.
_427
Corrected quantity
The quantity has been corrected.
_428
Operating divisions
Number of divisions operating.
_429
Quantitative incentive scheme base
Quantity constituting the base for the quantitative incentive scheme.
_430
Petitions filed
Number of petitions that have been filed.
_431
Bankruptcy petitions filed
Number of bankruptcy petitions that have been filed.
_432
Projects in process
Number of projects in process.
_433
Changes in capital structure
Number of modifications made to the capital structure of an entity.
_434
Detrimental legal filings against directors
The number of legal filings that are of a detrimental nature that have been filed against the directors.
_435
Number of failed businesses of directors
The number of failed businesses with which the directors have been associated.
_436
Professor
The number of professors.
_437
Seller
The number of sellers.
_438
Skilled worker
The number of skilled workers.
_439
Trademark represented
The number of trademarks represented.
_440
Number of quantitative incentive scheme units
Number of units allocated to a quantitative incentive scheme.
_441
Quantity in manufacturing process
Quantity currently in the manufacturing process.
_442
Number of units in the width of a layer
Number of units which make up the width of a layer.
_443
Number of units in the depth of a layer
Number of units which make up the depth of a layer.
ZZZ
Mutually defined
As agreed by the trading partners.