Struct edifact_types::d00b::C059
source · pub struct C059 {
pub _010: Option<String>,
pub _020: Option<String>,
pub _030: Option<String>,
pub _040: Option<String>,
}Expand description
C059 - STREET
Street address and/or PO Box number in a structured address: one to four lines.
Fields
_010: Option<String>Street and number or post office box identifier M an..35
_020: Option<String>Street and number or post office box identifier C an..35
_030: Option<String>Street and number or post office box identifier C an..35
_040: Option<String>Street and number or post office box identifier C an..35