pub struct DGS {Show 13 fields
pub _010: Option<String>,
pub _020: Option<C205>,
pub _030: Option<C234>,
pub _040: Option<C223>,
pub _050: Option<String>,
pub _060: Option<String>,
pub _070: Option<String>,
pub _080: Option<String>,
pub _090: Option<C235>,
pub _100: Option<C236>,
pub _110: Option<String>,
pub _120: Option<String>,
pub _130: Option<String>,
}Expand description
DGS - DANGEROUS GOODS
A segment to specify dangerous goods details related to the goods item.
Fields
_010: Option<String>DANGEROUS GOODS REGULATIONS CODE
Code specifying a dangerous goods regulation.
_020: Option<C205>C205 - HAZARD CODE
The identification of the dangerous goods in code.
_030: Option<C234>C234 - UNDG INFORMATION
Information on dangerous goods, taken from the United Nations Dangerous Goods classification.
_040: Option<C223>C223 - DANGEROUS GOODS SHIPMENT FLASHPOINT
Temperature at which a vapor can be ignited as per ISO 1523/73.
_050: Option<String>PACKAGING DANGER LEVEL CODE
Code specifying the level of danger for which the packaging must cater.
_060: Option<String>EMERGENCY PROCEDURE FOR SHIPS IDENTIFIER
To identify the emergency procedure number for ships transporting dangerous goods. Synonym: EMS Number.
_070: Option<String>HAZARD MEDICAL FIRST AID GUIDE IDENTIFIER
To identify a Medical First Aid Guide (MFAG) for hazardous goods.
_080: Option<String>TRANSPORT EMERGENCY CARD IDENTIFIER
To identify a transport emergency (TREM) card.
_090: Option<C235>C235 - HAZARD IDENTIFICATION PLACARD DETAILS
These numbers appear on the hazard identification placard required on the means of transport.
_100: Option<C236>C236 - DANGEROUS GOODS LABEL
Markings identifying the type of hazardous goods and similar information.
_110: Option<String>PACKING INSTRUCTION TYPE CODE
Code specifying a type of packing instruction.
_120: Option<String>HAZARDOUS MEANS OF TRANSPORT CATEGORY CODE
Code specifying the category of means of transport for carrying hazardous goods.
_130: Option<String>HAZARDOUS CARGO TRANSPORT AUTHORISATION CODE
Code specifying the authorisation for the transportation of hazardous cargo.